/* Schema.c generated by valac 0.34.6, the Vala compiler
 * generated from Schema.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; c-basic-offset: 2; tab-width: 2 -*- */
/*
 *
 * Copyright (C) 2017  Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Daniel Espinosa <esodan@gmail.com>
 */

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <gio/gio.h>


#define GXML_TYPE_DOM_EVENT_TARGET (gxml_dom_event_target_get_type ())
#define GXML_DOM_EVENT_TARGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT_TARGET, GXmlDomEventTarget))
#define GXML_IS_DOM_EVENT_TARGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT_TARGET))
#define GXML_DOM_EVENT_TARGET_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT_TARGET, GXmlDomEventTargetIface))

typedef struct _GXmlDomEventTarget GXmlDomEventTarget;
typedef struct _GXmlDomEventTargetIface GXmlDomEventTargetIface;

#define GXML_TYPE_DOM_EVENT_LISTENER (gxml_dom_event_listener_get_type ())
#define GXML_DOM_EVENT_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT_LISTENER, GXmlDomEventListener))
#define GXML_IS_DOM_EVENT_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT_LISTENER))
#define GXML_DOM_EVENT_LISTENER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT_LISTENER, GXmlDomEventListenerIface))

typedef struct _GXmlDomEventListener GXmlDomEventListener;
typedef struct _GXmlDomEventListenerIface GXmlDomEventListenerIface;

#define GXML_TYPE_DOM_EVENT (gxml_dom_event_get_type ())
#define GXML_DOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT, GXmlDomEvent))
#define GXML_IS_DOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT))
#define GXML_DOM_EVENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT, GXmlDomEventIface))

typedef struct _GXmlDomEvent GXmlDomEvent;
typedef struct _GXmlDomEventIface GXmlDomEventIface;

#define GXML_TYPE_DOM_TIME_STAMP (gxml_dom_time_stamp_get_type ())
#define GXML_DOM_TIME_STAMP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStamp))
#define GXML_DOM_TIME_STAMP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStampClass))
#define GXML_IS_DOM_TIME_STAMP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TIME_STAMP))
#define GXML_IS_DOM_TIME_STAMP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_TIME_STAMP))
#define GXML_DOM_TIME_STAMP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStampClass))

typedef struct _GXmlDomTimeStamp GXmlDomTimeStamp;
typedef struct _GXmlDomTimeStampClass GXmlDomTimeStampClass;

#define GXML_DOM_EVENT_TYPE_PHASE (gxml_dom_event_phase_get_type ())

#define GXML_TYPE_DOM_NODE (gxml_dom_node_get_type ())
#define GXML_DOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE, GXmlDomNode))
#define GXML_IS_DOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE))
#define GXML_DOM_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE, GXmlDomNodeIface))

typedef struct _GXmlDomNode GXmlDomNode;
typedef struct _GXmlDomNodeIface GXmlDomNodeIface;

#define GXML_DOM_NODE_TYPE_DOCUMENT_POSITION (gxml_dom_node_document_position_get_type ())

#define GXML_DOM_NODE_TYPE_NODE_TYPE (gxml_dom_node_node_type_get_type ())

#define GXML_TYPE_DOM_PARENT_NODE (gxml_dom_parent_node_get_type ())
#define GXML_DOM_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_PARENT_NODE, GXmlDomParentNode))
#define GXML_IS_DOM_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_PARENT_NODE))
#define GXML_DOM_PARENT_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_PARENT_NODE, GXmlDomParentNodeIface))

typedef struct _GXmlDomParentNode GXmlDomParentNode;
typedef struct _GXmlDomParentNodeIface GXmlDomParentNodeIface;

#define GXML_TYPE_DOM_NODE_LIST (gxml_dom_node_list_get_type ())
#define GXML_DOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_LIST, GXmlDomNodeList))
#define GXML_IS_DOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_LIST))
#define GXML_DOM_NODE_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE_LIST, GXmlDomNodeListIface))

typedef struct _GXmlDomNodeList GXmlDomNodeList;
typedef struct _GXmlDomNodeListIface GXmlDomNodeListIface;

#define GXML_TYPE_DOM_ELEMENT_LIST (gxml_dom_element_list_get_type ())
#define GXML_DOM_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementList))
#define GXML_DOM_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementListClass))
#define GXML_IS_DOM_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ELEMENT_LIST))
#define GXML_IS_DOM_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_ELEMENT_LIST))
#define GXML_DOM_ELEMENT_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementListClass))

typedef struct _GXmlDomElementList GXmlDomElementList;
typedef struct _GXmlDomElementListClass GXmlDomElementListClass;

#define GXML_TYPE_DOM_HTML_COLLECTION (gxml_dom_html_collection_get_type ())
#define GXML_DOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_HTML_COLLECTION, GXmlDomHTMLCollection))
#define GXML_IS_DOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_HTML_COLLECTION))
#define GXML_DOM_HTML_COLLECTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_HTML_COLLECTION, GXmlDomHTMLCollectionIface))

typedef struct _GXmlDomHTMLCollection GXmlDomHTMLCollection;
typedef struct _GXmlDomHTMLCollectionIface GXmlDomHTMLCollectionIface;

#define GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE (gxml_dom_non_element_parent_node_get_type ())
#define GXML_DOM_NON_ELEMENT_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE, GXmlDomNonElementParentNode))
#define GXML_IS_DOM_NON_ELEMENT_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE))
#define GXML_DOM_NON_ELEMENT_PARENT_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE, GXmlDomNonElementParentNodeIface))

typedef struct _GXmlDomNonElementParentNode GXmlDomNonElementParentNode;
typedef struct _GXmlDomNonElementParentNodeIface GXmlDomNonElementParentNodeIface;

#define GXML_TYPE_DOM_DOCUMENT (gxml_dom_document_get_type ())
#define GXML_DOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT, GXmlDomDocument))
#define GXML_IS_DOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT))
#define GXML_DOM_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT, GXmlDomDocumentIface))

typedef struct _GXmlDomDocument GXmlDomDocument;
typedef struct _GXmlDomDocumentIface GXmlDomDocumentIface;

#define GXML_TYPE_DOM_DOCUMENT_FRAGMENT (gxml_dom_document_fragment_get_type ())
#define GXML_DOM_DOCUMENT_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT, GXmlDomDocumentFragment))
#define GXML_IS_DOM_DOCUMENT_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT))
#define GXML_DOM_DOCUMENT_FRAGMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT, GXmlDomDocumentFragmentIface))

typedef struct _GXmlDomDocumentFragment GXmlDomDocumentFragment;
typedef struct _GXmlDomDocumentFragmentIface GXmlDomDocumentFragmentIface;

#define GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE (gxml_dom_non_document_type_child_node_get_type ())
#define GXML_DOM_NON_DOCUMENT_TYPE_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE, GXmlDomNonDocumentTypeChildNode))
#define GXML_IS_DOM_NON_DOCUMENT_TYPE_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE))
#define GXML_DOM_NON_DOCUMENT_TYPE_CHILD_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE, GXmlDomNonDocumentTypeChildNodeIface))

typedef struct _GXmlDomNonDocumentTypeChildNode GXmlDomNonDocumentTypeChildNode;
typedef struct _GXmlDomNonDocumentTypeChildNodeIface GXmlDomNonDocumentTypeChildNodeIface;

#define GXML_TYPE_DOM_CHILD_NODE (gxml_dom_child_node_get_type ())
#define GXML_DOM_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_CHILD_NODE, GXmlDomChildNode))
#define GXML_IS_DOM_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_CHILD_NODE))
#define GXML_DOM_CHILD_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_CHILD_NODE, GXmlDomChildNodeIface))

typedef struct _GXmlDomChildNode GXmlDomChildNode;
typedef struct _GXmlDomChildNodeIface GXmlDomChildNodeIface;

#define GXML_TYPE_DOM_CHARACTER_DATA (gxml_dom_character_data_get_type ())
#define GXML_DOM_CHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_CHARACTER_DATA, GXmlDomCharacterData))
#define GXML_IS_DOM_CHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_CHARACTER_DATA))
#define GXML_DOM_CHARACTER_DATA_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_CHARACTER_DATA, GXmlDomCharacterDataIface))

typedef struct _GXmlDomCharacterData GXmlDomCharacterData;
typedef struct _GXmlDomCharacterDataIface GXmlDomCharacterDataIface;

#define GXML_TYPE_DOM_TEXT (gxml_dom_text_get_type ())
#define GXML_DOM_TEXT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TEXT, GXmlDomText))
#define GXML_IS_DOM_TEXT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TEXT))
#define GXML_DOM_TEXT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TEXT, GXmlDomTextIface))

typedef struct _GXmlDomText GXmlDomText;
typedef struct _GXmlDomTextIface GXmlDomTextIface;

#define GXML_TYPE_DOM_COMMENT (gxml_dom_comment_get_type ())
#define GXML_DOM_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_COMMENT, GXmlDomComment))
#define GXML_IS_DOM_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_COMMENT))
#define GXML_DOM_COMMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_COMMENT, GXmlDomCommentIface))

typedef struct _GXmlDomComment GXmlDomComment;
typedef struct _GXmlDomCommentIface GXmlDomCommentIface;

#define GXML_TYPE_DOM_PROCESSING_INSTRUCTION (gxml_dom_processing_instruction_get_type ())
#define GXML_DOM_PROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION, GXmlDomProcessingInstruction))
#define GXML_IS_DOM_PROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION))
#define GXML_DOM_PROCESSING_INSTRUCTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION, GXmlDomProcessingInstructionIface))

typedef struct _GXmlDomProcessingInstruction GXmlDomProcessingInstruction;
typedef struct _GXmlDomProcessingInstructionIface GXmlDomProcessingInstructionIface;

#define GXML_TYPE_DOM_RANGE (gxml_dom_range_get_type ())
#define GXML_DOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_RANGE, GXmlDomRange))
#define GXML_IS_DOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_RANGE))
#define GXML_DOM_RANGE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_RANGE, GXmlDomRangeIface))

typedef struct _GXmlDomRange GXmlDomRange;
typedef struct _GXmlDomRangeIface GXmlDomRangeIface;

#define GXML_DOM_RANGE_TYPE_BOUNDARY_POINTS (gxml_dom_range_boundary_points_get_type ())

#define GXML_TYPE_DOM_NODE_FILTER (gxml_dom_node_filter_get_type ())
#define GXML_DOM_NODE_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilter))
#define GXML_DOM_NODE_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilterClass))
#define GXML_IS_DOM_NODE_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_FILTER))
#define GXML_IS_DOM_NODE_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_NODE_FILTER))
#define GXML_DOM_NODE_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilterClass))

typedef struct _GXmlDomNodeFilter GXmlDomNodeFilter;
typedef struct _GXmlDomNodeFilterClass GXmlDomNodeFilterClass;

#define GXML_TYPE_DOM_NODE_ITERATOR (gxml_dom_node_iterator_get_type ())
#define GXML_DOM_NODE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_ITERATOR, GXmlDomNodeIterator))
#define GXML_IS_DOM_NODE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_ITERATOR))
#define GXML_DOM_NODE_ITERATOR_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE_ITERATOR, GXmlDomNodeIteratorIface))

typedef struct _GXmlDomNodeIterator GXmlDomNodeIterator;
typedef struct _GXmlDomNodeIteratorIface GXmlDomNodeIteratorIface;

#define GXML_TYPE_DOM_TREE_WALKER (gxml_dom_tree_walker_get_type ())
#define GXML_DOM_TREE_WALKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TREE_WALKER, GXmlDomTreeWalker))
#define GXML_IS_DOM_TREE_WALKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TREE_WALKER))
#define GXML_DOM_TREE_WALKER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TREE_WALKER, GXmlDomTreeWalkerIface))

typedef struct _GXmlDomTreeWalker GXmlDomTreeWalker;
typedef struct _GXmlDomTreeWalkerIface GXmlDomTreeWalkerIface;

#define GXML_TYPE_DOM_IMPLEMENTATION (gxml_dom_implementation_get_type ())
#define GXML_DOM_IMPLEMENTATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_IMPLEMENTATION, GXmlDomImplementation))
#define GXML_IS_DOM_IMPLEMENTATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_IMPLEMENTATION))
#define GXML_DOM_IMPLEMENTATION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_IMPLEMENTATION, GXmlDomImplementationIface))

typedef struct _GXmlDomImplementation GXmlDomImplementation;
typedef struct _GXmlDomImplementationIface GXmlDomImplementationIface;

#define GXML_TYPE_DOM_DOCUMENT_TYPE (gxml_dom_document_type_get_type ())
#define GXML_DOM_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE, GXmlDomDocumentType))
#define GXML_IS_DOM_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE))
#define GXML_DOM_DOCUMENT_TYPE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE, GXmlDomDocumentTypeIface))

typedef struct _GXmlDomDocumentType GXmlDomDocumentType;
typedef struct _GXmlDomDocumentTypeIface GXmlDomDocumentTypeIface;

#define GXML_TYPE_DOM_XML_DOCUMENT (gxml_dom_xml_document_get_type ())
#define GXML_DOM_XML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_XML_DOCUMENT, GXmlDomXMLDocument))
#define GXML_IS_DOM_XML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_XML_DOCUMENT))
#define GXML_DOM_XML_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_XML_DOCUMENT, GXmlDomXMLDocumentIface))

typedef struct _GXmlDomXMLDocument GXmlDomXMLDocument;
typedef struct _GXmlDomXMLDocumentIface GXmlDomXMLDocumentIface;

#define GXML_TYPE_NODE (gxml_node_get_type ())
#define GXML_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NODE, GXmlNode))
#define GXML_IS_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NODE))
#define GXML_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_NODE, GXmlNodeIface))

typedef struct _GXmlNode GXmlNode;
typedef struct _GXmlNodeIface GXmlNodeIface;

#define GXML_TYPE_ELEMENT_LIST (gxml_element_list_get_type ())
#define GXML_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_ELEMENT_LIST, GXmlElementList))
#define GXML_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_ELEMENT_LIST, GXmlElementListClass))
#define GXML_IS_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_ELEMENT_LIST))
#define GXML_IS_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_ELEMENT_LIST))
#define GXML_ELEMENT_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_ELEMENT_LIST, GXmlElementListClass))

typedef struct _GXmlElementList GXmlElementList;
typedef struct _GXmlElementListClass GXmlElementListClass;

#define GXML_TYPE_NAMESPACE (gxml_namespace_get_type ())
#define GXML_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NAMESPACE, GXmlNamespace))
#define GXML_IS_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NAMESPACE))
#define GXML_NAMESPACE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_NAMESPACE, GXmlNamespaceIface))

typedef struct _GXmlNamespace GXmlNamespace;
typedef struct _GXmlNamespaceIface GXmlNamespaceIface;

#define GXML_TYPE_NODE_TYPE (gxml_node_type_get_type ())

#define GXML_TYPE_DOCUMENT (gxml_document_get_type ())
#define GXML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOCUMENT, GXmlDocument))
#define GXML_IS_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOCUMENT))
#define GXML_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOCUMENT, GXmlDocumentIface))

typedef struct _GXmlDocument GXmlDocument;
typedef struct _GXmlDocumentIface GXmlDocumentIface;

#define GXML_TYPE_DOM_ELEMENT (gxml_dom_element_get_type ())
#define GXML_DOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ELEMENT, GXmlDomElement))
#define GXML_IS_DOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ELEMENT))
#define GXML_DOM_ELEMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_ELEMENT, GXmlDomElementIface))

typedef struct _GXmlDomElement GXmlDomElement;
typedef struct _GXmlDomElementIface GXmlDomElementIface;

#define GXML_TYPE_DOM_TOKEN_LIST (gxml_dom_token_list_get_type ())
#define GXML_DOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TOKEN_LIST, GXmlDomTokenList))
#define GXML_IS_DOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TOKEN_LIST))
#define GXML_DOM_TOKEN_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TOKEN_LIST, GXmlDomTokenListIface))

typedef struct _GXmlDomTokenList GXmlDomTokenList;
typedef struct _GXmlDomTokenListIface GXmlDomTokenListIface;

#define GXML_TYPE_DOM_NAMED_NODE_MAP (gxml_dom_named_node_map_get_type ())
#define GXML_DOM_NAMED_NODE_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP, GXmlDomNamedNodeMap))
#define GXML_IS_DOM_NAMED_NODE_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP))
#define GXML_DOM_NAMED_NODE_MAP_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP, GXmlDomNamedNodeMapIface))

typedef struct _GXmlDomNamedNodeMap GXmlDomNamedNodeMap;
typedef struct _GXmlDomNamedNodeMapIface GXmlDomNamedNodeMapIface;

#define GXML_TYPE_IXSD_SCHEMA (gxml_ixsd_schema_get_type ())
#define GXML_IXSD_SCHEMA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_SCHEMA, GXmlIXsdSchema))
#define GXML_IS_IXSD_SCHEMA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_SCHEMA))
#define GXML_IXSD_SCHEMA_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_SCHEMA, GXmlIXsdSchemaIface))

typedef struct _GXmlIXsdSchema GXmlIXsdSchema;
typedef struct _GXmlIXsdSchemaIface GXmlIXsdSchemaIface;

#define GXML_TYPE_GOM_COLLECTION (gxml_gom_collection_get_type ())
#define GXML_GOM_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_COLLECTION, GXmlGomCollection))
#define GXML_IS_GOM_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_COLLECTION))
#define GXML_GOM_COLLECTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_GOM_COLLECTION, GXmlGomCollectionIface))

typedef struct _GXmlGomCollection GXmlGomCollection;
typedef struct _GXmlGomCollectionIface GXmlGomCollectionIface;

#define GXML_TYPE_GOM_NODE (gxml_gom_node_get_type ())
#define GXML_GOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_NODE, GXmlGomNode))
#define GXML_GOM_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_NODE, GXmlGomNodeClass))
#define GXML_IS_GOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_NODE))
#define GXML_IS_GOM_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_NODE))
#define GXML_GOM_NODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_NODE, GXmlGomNodeClass))

typedef struct _GXmlGomNode GXmlGomNode;
typedef struct _GXmlGomNodeClass GXmlGomNodeClass;

#define GXML_TYPE_GOM_ELEMENT (gxml_gom_element_get_type ())
#define GXML_GOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_ELEMENT, GXmlGomElement))
#define GXML_GOM_ELEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_ELEMENT, GXmlGomElementClass))
#define GXML_IS_GOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_ELEMENT))
#define GXML_IS_GOM_ELEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_ELEMENT))
#define GXML_GOM_ELEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_ELEMENT, GXmlGomElementClass))

typedef struct _GXmlGomElement GXmlGomElement;
typedef struct _GXmlGomElementClass GXmlGomElementClass;

#define GXML_TYPE_IXSD_LIST (gxml_ixsd_list_get_type ())
#define GXML_IXSD_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_LIST, GXmlIXsdList))
#define GXML_IS_IXSD_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_LIST))
#define GXML_IXSD_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_LIST, GXmlIXsdListIface))

typedef struct _GXmlIXsdList GXmlIXsdList;
typedef struct _GXmlIXsdListIface GXmlIXsdListIface;

#define GXML_TYPE_IXSD_LIST_ELEMENTS (gxml_ixsd_list_elements_get_type ())
#define GXML_IXSD_LIST_ELEMENTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_LIST_ELEMENTS, GXmlIXsdListElements))
#define GXML_IS_IXSD_LIST_ELEMENTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_LIST_ELEMENTS))
#define GXML_IXSD_LIST_ELEMENTS_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_LIST_ELEMENTS, GXmlIXsdListElementsIface))

typedef struct _GXmlIXsdListElements GXmlIXsdListElements;
typedef struct _GXmlIXsdListElementsIface GXmlIXsdListElementsIface;

#define GXML_TYPE_IXSD_LIST_SIMPLE_TYPES (gxml_ixsd_list_simple_types_get_type ())
#define GXML_IXSD_LIST_SIMPLE_TYPES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_LIST_SIMPLE_TYPES, GXmlIXsdListSimpleTypes))
#define GXML_IS_IXSD_LIST_SIMPLE_TYPES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_LIST_SIMPLE_TYPES))
#define GXML_IXSD_LIST_SIMPLE_TYPES_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_LIST_SIMPLE_TYPES, GXmlIXsdListSimpleTypesIface))

typedef struct _GXmlIXsdListSimpleTypes GXmlIXsdListSimpleTypes;
typedef struct _GXmlIXsdListSimpleTypesIface GXmlIXsdListSimpleTypesIface;

#define GXML_TYPE_IXSD_LIST_COMPLEX_TYPES (gxml_ixsd_list_complex_types_get_type ())
#define GXML_IXSD_LIST_COMPLEX_TYPES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_LIST_COMPLEX_TYPES, GXmlIXsdListComplexTypes))
#define GXML_IS_IXSD_LIST_COMPLEX_TYPES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_LIST_COMPLEX_TYPES))
#define GXML_IXSD_LIST_COMPLEX_TYPES_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_LIST_COMPLEX_TYPES, GXmlIXsdListComplexTypesIface))

typedef struct _GXmlIXsdListComplexTypes GXmlIXsdListComplexTypes;
typedef struct _GXmlIXsdListComplexTypesIface GXmlIXsdListComplexTypesIface;

#define GXML_TYPE_IXSD_BASE_TYPE (gxml_ixsd_base_type_get_type ())
#define GXML_IXSD_BASE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_BASE_TYPE, GXmlIXsdBaseType))
#define GXML_IS_IXSD_BASE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_BASE_TYPE))
#define GXML_IXSD_BASE_TYPE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_BASE_TYPE, GXmlIXsdBaseTypeIface))

typedef struct _GXmlIXsdBaseType GXmlIXsdBaseType;
typedef struct _GXmlIXsdBaseTypeIface GXmlIXsdBaseTypeIface;

#define GXML_TYPE_IXSD_ANNOTATION (gxml_ixsd_annotation_get_type ())
#define GXML_IXSD_ANNOTATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_ANNOTATION, GXmlIXsdAnnotation))
#define GXML_IS_IXSD_ANNOTATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_ANNOTATION))
#define GXML_IXSD_ANNOTATION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_ANNOTATION, GXmlIXsdAnnotationIface))

typedef struct _GXmlIXsdAnnotation GXmlIXsdAnnotation;
typedef struct _GXmlIXsdAnnotationIface GXmlIXsdAnnotationIface;

#define GXML_TYPE_IXSD_SIMPLE_TYPE (gxml_ixsd_simple_type_get_type ())
#define GXML_IXSD_SIMPLE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_SIMPLE_TYPE, GXmlIXsdSimpleType))
#define GXML_IS_IXSD_SIMPLE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_SIMPLE_TYPE))
#define GXML_IXSD_SIMPLE_TYPE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_SIMPLE_TYPE, GXmlIXsdSimpleTypeIface))

typedef struct _GXmlIXsdSimpleType GXmlIXsdSimpleType;
typedef struct _GXmlIXsdSimpleTypeIface GXmlIXsdSimpleTypeIface;

#define GXML_TYPE_IXSD_TYPE_DEF (gxml_ixsd_type_def_get_type ())
#define GXML_IXSD_TYPE_DEF(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_TYPE_DEF, GXmlIXsdTypeDef))
#define GXML_IS_IXSD_TYPE_DEF(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_TYPE_DEF))
#define GXML_IXSD_TYPE_DEF_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_TYPE_DEF, GXmlIXsdTypeDefIface))

typedef struct _GXmlIXsdTypeDef GXmlIXsdTypeDef;
typedef struct _GXmlIXsdTypeDefIface GXmlIXsdTypeDefIface;

#define GXML_TYPE_IXSD_TYPE_LIST (gxml_ixsd_type_list_get_type ())
#define GXML_IXSD_TYPE_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_TYPE_LIST, GXmlIXsdTypeList))
#define GXML_IS_IXSD_TYPE_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_TYPE_LIST))
#define GXML_IXSD_TYPE_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_TYPE_LIST, GXmlIXsdTypeListIface))

typedef struct _GXmlIXsdTypeList GXmlIXsdTypeList;
typedef struct _GXmlIXsdTypeListIface GXmlIXsdTypeListIface;

#define GXML_TYPE_IXSD_TYPE_UNION (gxml_ixsd_type_union_get_type ())
#define GXML_IXSD_TYPE_UNION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_TYPE_UNION, GXmlIXsdTypeUnion))
#define GXML_IS_IXSD_TYPE_UNION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_TYPE_UNION))
#define GXML_IXSD_TYPE_UNION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_TYPE_UNION, GXmlIXsdTypeUnionIface))

typedef struct _GXmlIXsdTypeUnion GXmlIXsdTypeUnion;
typedef struct _GXmlIXsdTypeUnionIface GXmlIXsdTypeUnionIface;

#define GXML_TYPE_IXSD_TYPE_RESTRICTION (gxml_ixsd_type_restriction_get_type ())
#define GXML_IXSD_TYPE_RESTRICTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION, GXmlIXsdTypeRestriction))
#define GXML_IS_IXSD_TYPE_RESTRICTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION))
#define GXML_IXSD_TYPE_RESTRICTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION, GXmlIXsdTypeRestrictionIface))

typedef struct _GXmlIXsdTypeRestriction GXmlIXsdTypeRestriction;
typedef struct _GXmlIXsdTypeRestrictionIface GXmlIXsdTypeRestrictionIface;

#define GXML_TYPE_IXSD_LIST_TYPE_RESTRICTION_ENUMERATIONS (gxml_ixsd_list_type_restriction_enumerations_get_type ())
#define GXML_IXSD_LIST_TYPE_RESTRICTION_ENUMERATIONS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_LIST_TYPE_RESTRICTION_ENUMERATIONS, GXmlIXsdListTypeRestrictionEnumerations))
#define GXML_IS_IXSD_LIST_TYPE_RESTRICTION_ENUMERATIONS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_LIST_TYPE_RESTRICTION_ENUMERATIONS))
#define GXML_IXSD_LIST_TYPE_RESTRICTION_ENUMERATIONS_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_LIST_TYPE_RESTRICTION_ENUMERATIONS, GXmlIXsdListTypeRestrictionEnumerationsIface))

typedef struct _GXmlIXsdListTypeRestrictionEnumerations GXmlIXsdListTypeRestrictionEnumerations;
typedef struct _GXmlIXsdListTypeRestrictionEnumerationsIface GXmlIXsdListTypeRestrictionEnumerationsIface;

#define GXML_TYPE_IXSD_LIST_TYPE_RESTRICTION_WHITE_SPACES (gxml_ixsd_list_type_restriction_white_spaces_get_type ())
#define GXML_IXSD_LIST_TYPE_RESTRICTION_WHITE_SPACES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_LIST_TYPE_RESTRICTION_WHITE_SPACES, GXmlIXsdListTypeRestrictionWhiteSpaces))
#define GXML_IS_IXSD_LIST_TYPE_RESTRICTION_WHITE_SPACES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_LIST_TYPE_RESTRICTION_WHITE_SPACES))
#define GXML_IXSD_LIST_TYPE_RESTRICTION_WHITE_SPACES_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_LIST_TYPE_RESTRICTION_WHITE_SPACES, GXmlIXsdListTypeRestrictionWhiteSpacesIface))

typedef struct _GXmlIXsdListTypeRestrictionWhiteSpaces GXmlIXsdListTypeRestrictionWhiteSpaces;
typedef struct _GXmlIXsdListTypeRestrictionWhiteSpacesIface GXmlIXsdListTypeRestrictionWhiteSpacesIface;

#define GXML_TYPE_IXSD_TYPE_RESTRICTION_DEF (gxml_ixsd_type_restriction_def_get_type ())
#define GXML_IXSD_TYPE_RESTRICTION_DEF(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_DEF, GXmlIXsdTypeRestrictionDef))
#define GXML_IS_IXSD_TYPE_RESTRICTION_DEF(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_DEF))
#define GXML_IXSD_TYPE_RESTRICTION_DEF_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_DEF, GXmlIXsdTypeRestrictionDefIface))

typedef struct _GXmlIXsdTypeRestrictionDef GXmlIXsdTypeRestrictionDef;
typedef struct _GXmlIXsdTypeRestrictionDefIface GXmlIXsdTypeRestrictionDefIface;

#define GXML_TYPE_IXSD_TYPE_RESTRICTION_MIN_EXCLUSIVE (gxml_ixsd_type_restriction_min_exclusive_get_type ())
#define GXML_IXSD_TYPE_RESTRICTION_MIN_EXCLUSIVE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_MIN_EXCLUSIVE, GXmlIXsdTypeRestrictionMinExclusive))
#define GXML_IS_IXSD_TYPE_RESTRICTION_MIN_EXCLUSIVE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_MIN_EXCLUSIVE))
#define GXML_IXSD_TYPE_RESTRICTION_MIN_EXCLUSIVE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_MIN_EXCLUSIVE, GXmlIXsdTypeRestrictionMinExclusiveIface))

typedef struct _GXmlIXsdTypeRestrictionMinExclusive GXmlIXsdTypeRestrictionMinExclusive;
typedef struct _GXmlIXsdTypeRestrictionMinExclusiveIface GXmlIXsdTypeRestrictionMinExclusiveIface;

#define GXML_TYPE_IXSD_TYPE_RESTRICTION_MIN_INCLUSIVE (gxml_ixsd_type_restriction_min_inclusive_get_type ())
#define GXML_IXSD_TYPE_RESTRICTION_MIN_INCLUSIVE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_MIN_INCLUSIVE, GXmlIXsdTypeRestrictionMinInclusive))
#define GXML_IS_IXSD_TYPE_RESTRICTION_MIN_INCLUSIVE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_MIN_INCLUSIVE))
#define GXML_IXSD_TYPE_RESTRICTION_MIN_INCLUSIVE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_MIN_INCLUSIVE, GXmlIXsdTypeRestrictionMinInclusiveIface))

typedef struct _GXmlIXsdTypeRestrictionMinInclusive GXmlIXsdTypeRestrictionMinInclusive;
typedef struct _GXmlIXsdTypeRestrictionMinInclusiveIface GXmlIXsdTypeRestrictionMinInclusiveIface;

#define GXML_TYPE_IXSD_TYPE_RESTRICTION_MAX_EXCLUSIVE (gxml_ixsd_type_restriction_max_exclusive_get_type ())
#define GXML_IXSD_TYPE_RESTRICTION_MAX_EXCLUSIVE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_MAX_EXCLUSIVE, GXmlIXsdTypeRestrictionMaxExclusive))
#define GXML_IS_IXSD_TYPE_RESTRICTION_MAX_EXCLUSIVE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_MAX_EXCLUSIVE))
#define GXML_IXSD_TYPE_RESTRICTION_MAX_EXCLUSIVE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_MAX_EXCLUSIVE, GXmlIXsdTypeRestrictionMaxExclusiveIface))

typedef struct _GXmlIXsdTypeRestrictionMaxExclusive GXmlIXsdTypeRestrictionMaxExclusive;
typedef struct _GXmlIXsdTypeRestrictionMaxExclusiveIface GXmlIXsdTypeRestrictionMaxExclusiveIface;

#define GXML_TYPE_IXSD_TYPE_RESTRICTION_MAX_INCLUSIVE (gxml_ixsd_type_restriction_max_inclusive_get_type ())
#define GXML_IXSD_TYPE_RESTRICTION_MAX_INCLUSIVE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_MAX_INCLUSIVE, GXmlIXsdTypeRestrictionMaxInclusive))
#define GXML_IS_IXSD_TYPE_RESTRICTION_MAX_INCLUSIVE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_MAX_INCLUSIVE))
#define GXML_IXSD_TYPE_RESTRICTION_MAX_INCLUSIVE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_MAX_INCLUSIVE, GXmlIXsdTypeRestrictionMaxInclusiveIface))

typedef struct _GXmlIXsdTypeRestrictionMaxInclusive GXmlIXsdTypeRestrictionMaxInclusive;
typedef struct _GXmlIXsdTypeRestrictionMaxInclusiveIface GXmlIXsdTypeRestrictionMaxInclusiveIface;

#define GXML_TYPE_IXSD_TYPE_RESTRICTION_TOTAL_DIGITS (gxml_ixsd_type_restriction_total_digits_get_type ())
#define GXML_IXSD_TYPE_RESTRICTION_TOTAL_DIGITS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_TOTAL_DIGITS, GXmlIXsdTypeRestrictionTotalDigits))
#define GXML_IS_IXSD_TYPE_RESTRICTION_TOTAL_DIGITS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_TOTAL_DIGITS))
#define GXML_IXSD_TYPE_RESTRICTION_TOTAL_DIGITS_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_TOTAL_DIGITS, GXmlIXsdTypeRestrictionTotalDigitsIface))

typedef struct _GXmlIXsdTypeRestrictionTotalDigits GXmlIXsdTypeRestrictionTotalDigits;
typedef struct _GXmlIXsdTypeRestrictionTotalDigitsIface GXmlIXsdTypeRestrictionTotalDigitsIface;

#define GXML_TYPE_IXSD_TYPE_RESTRICTION_FRACTION_DIGITS (gxml_ixsd_type_restriction_fraction_digits_get_type ())
#define GXML_IXSD_TYPE_RESTRICTION_FRACTION_DIGITS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_FRACTION_DIGITS, GXmlIXsdTypeRestrictionFractionDigits))
#define GXML_IS_IXSD_TYPE_RESTRICTION_FRACTION_DIGITS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_FRACTION_DIGITS))
#define GXML_IXSD_TYPE_RESTRICTION_FRACTION_DIGITS_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_FRACTION_DIGITS, GXmlIXsdTypeRestrictionFractionDigitsIface))

typedef struct _GXmlIXsdTypeRestrictionFractionDigits GXmlIXsdTypeRestrictionFractionDigits;
typedef struct _GXmlIXsdTypeRestrictionFractionDigitsIface GXmlIXsdTypeRestrictionFractionDigitsIface;

#define GXML_TYPE_IXSD_TYPE_RESTRICTION_LENGTH (gxml_ixsd_type_restriction_length_get_type ())
#define GXML_IXSD_TYPE_RESTRICTION_LENGTH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_LENGTH, GXmlIXsdTypeRestrictionLength))
#define GXML_IS_IXSD_TYPE_RESTRICTION_LENGTH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_LENGTH))
#define GXML_IXSD_TYPE_RESTRICTION_LENGTH_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_LENGTH, GXmlIXsdTypeRestrictionLengthIface))

typedef struct _GXmlIXsdTypeRestrictionLength GXmlIXsdTypeRestrictionLength;
typedef struct _GXmlIXsdTypeRestrictionLengthIface GXmlIXsdTypeRestrictionLengthIface;

#define GXML_TYPE_IXSD_TYPE_RESTRICTION_MIN_LENGTH (gxml_ixsd_type_restriction_min_length_get_type ())
#define GXML_IXSD_TYPE_RESTRICTION_MIN_LENGTH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_MIN_LENGTH, GXmlIXsdTypeRestrictionMinLength))
#define GXML_IS_IXSD_TYPE_RESTRICTION_MIN_LENGTH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_MIN_LENGTH))
#define GXML_IXSD_TYPE_RESTRICTION_MIN_LENGTH_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_MIN_LENGTH, GXmlIXsdTypeRestrictionMinLengthIface))

typedef struct _GXmlIXsdTypeRestrictionMinLength GXmlIXsdTypeRestrictionMinLength;
typedef struct _GXmlIXsdTypeRestrictionMinLengthIface GXmlIXsdTypeRestrictionMinLengthIface;

#define GXML_TYPE_IXSD_TYPE_RESTRICTION_MAX_LENGTH (gxml_ixsd_type_restriction_max_length_get_type ())
#define GXML_IXSD_TYPE_RESTRICTION_MAX_LENGTH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_MAX_LENGTH, GXmlIXsdTypeRestrictionMaxLength))
#define GXML_IS_IXSD_TYPE_RESTRICTION_MAX_LENGTH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_MAX_LENGTH))
#define GXML_IXSD_TYPE_RESTRICTION_MAX_LENGTH_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_MAX_LENGTH, GXmlIXsdTypeRestrictionMaxLengthIface))

typedef struct _GXmlIXsdTypeRestrictionMaxLength GXmlIXsdTypeRestrictionMaxLength;
typedef struct _GXmlIXsdTypeRestrictionMaxLengthIface GXmlIXsdTypeRestrictionMaxLengthIface;

#define GXML_TYPE_IXSD_TYPE_RESTRICTION_ENUMERATION (gxml_ixsd_type_restriction_enumeration_get_type ())
#define GXML_IXSD_TYPE_RESTRICTION_ENUMERATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_ENUMERATION, GXmlIXsdTypeRestrictionEnumeration))
#define GXML_IS_IXSD_TYPE_RESTRICTION_ENUMERATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_ENUMERATION))
#define GXML_IXSD_TYPE_RESTRICTION_ENUMERATION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_ENUMERATION, GXmlIXsdTypeRestrictionEnumerationIface))

typedef struct _GXmlIXsdTypeRestrictionEnumeration GXmlIXsdTypeRestrictionEnumeration;
typedef struct _GXmlIXsdTypeRestrictionEnumerationIface GXmlIXsdTypeRestrictionEnumerationIface;

#define GXML_TYPE_IXSD_TYPE_RESTRICTION_WHITE_SPACE (gxml_ixsd_type_restriction_white_space_get_type ())
#define GXML_IXSD_TYPE_RESTRICTION_WHITE_SPACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_WHITE_SPACE, GXmlIXsdTypeRestrictionWhiteSpace))
#define GXML_IS_IXSD_TYPE_RESTRICTION_WHITE_SPACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_WHITE_SPACE))
#define GXML_IXSD_TYPE_RESTRICTION_WHITE_SPACE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_WHITE_SPACE, GXmlIXsdTypeRestrictionWhiteSpaceIface))

typedef struct _GXmlIXsdTypeRestrictionWhiteSpace GXmlIXsdTypeRestrictionWhiteSpace;
typedef struct _GXmlIXsdTypeRestrictionWhiteSpaceIface GXmlIXsdTypeRestrictionWhiteSpaceIface;

#define GXML_TYPE_IXSD_TYPE_RESTRICTION_PATTERN (gxml_ixsd_type_restriction_pattern_get_type ())
#define GXML_IXSD_TYPE_RESTRICTION_PATTERN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_PATTERN, GXmlIXsdTypeRestrictionPattern))
#define GXML_IS_IXSD_TYPE_RESTRICTION_PATTERN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_PATTERN))
#define GXML_IXSD_TYPE_RESTRICTION_PATTERN_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_PATTERN, GXmlIXsdTypeRestrictionPatternIface))

typedef struct _GXmlIXsdTypeRestrictionPattern GXmlIXsdTypeRestrictionPattern;
typedef struct _GXmlIXsdTypeRestrictionPatternIface GXmlIXsdTypeRestrictionPatternIface;

#define GXML_TYPE_IXSD_TYPE_RESTRICTION_ASSERTION (gxml_ixsd_type_restriction_assertion_get_type ())
#define GXML_IXSD_TYPE_RESTRICTION_ASSERTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_ASSERTION, GXmlIXsdTypeRestrictionAssertion))
#define GXML_IS_IXSD_TYPE_RESTRICTION_ASSERTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_ASSERTION))
#define GXML_IXSD_TYPE_RESTRICTION_ASSERTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_ASSERTION, GXmlIXsdTypeRestrictionAssertionIface))

typedef struct _GXmlIXsdTypeRestrictionAssertion GXmlIXsdTypeRestrictionAssertion;
typedef struct _GXmlIXsdTypeRestrictionAssertionIface GXmlIXsdTypeRestrictionAssertionIface;

#define GXML_TYPE_IXSD_TYPE_RESTRICTION_EXPLICIT_TIMEZONE (gxml_ixsd_type_restriction_explicit_timezone_get_type ())
#define GXML_IXSD_TYPE_RESTRICTION_EXPLICIT_TIMEZONE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_EXPLICIT_TIMEZONE, GXmlIXsdTypeRestrictionExplicitTimezone))
#define GXML_IS_IXSD_TYPE_RESTRICTION_EXPLICIT_TIMEZONE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_EXPLICIT_TIMEZONE))
#define GXML_IXSD_TYPE_RESTRICTION_EXPLICIT_TIMEZONE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_TYPE_RESTRICTION_EXPLICIT_TIMEZONE, GXmlIXsdTypeRestrictionExplicitTimezoneIface))

typedef struct _GXmlIXsdTypeRestrictionExplicitTimezone GXmlIXsdTypeRestrictionExplicitTimezone;
typedef struct _GXmlIXsdTypeRestrictionExplicitTimezoneIface GXmlIXsdTypeRestrictionExplicitTimezoneIface;

#define GXML_TYPE_IXSD_COMPLEX_TYPE (gxml_ixsd_complex_type_get_type ())
#define GXML_IXSD_COMPLEX_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_COMPLEX_TYPE, GXmlIXsdComplexType))
#define GXML_IS_IXSD_COMPLEX_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_COMPLEX_TYPE))
#define GXML_IXSD_COMPLEX_TYPE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_COMPLEX_TYPE, GXmlIXsdComplexTypeIface))

typedef struct _GXmlIXsdComplexType GXmlIXsdComplexType;
typedef struct _GXmlIXsdComplexTypeIface GXmlIXsdComplexTypeIface;

#define GXML_TYPE_IXSD_BASE_CONTENT (gxml_ixsd_base_content_get_type ())
#define GXML_IXSD_BASE_CONTENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_BASE_CONTENT, GXmlIXsdBaseContent))
#define GXML_IS_IXSD_BASE_CONTENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_BASE_CONTENT))
#define GXML_IXSD_BASE_CONTENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_BASE_CONTENT, GXmlIXsdBaseContentIface))

typedef struct _GXmlIXsdBaseContent GXmlIXsdBaseContent;
typedef struct _GXmlIXsdBaseContentIface GXmlIXsdBaseContentIface;

#define GXML_TYPE_IXSD_LIST_ATTRIBUTES (gxml_ixsd_list_attributes_get_type ())
#define GXML_IXSD_LIST_ATTRIBUTES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_LIST_ATTRIBUTES, GXmlIXsdListAttributes))
#define GXML_IS_IXSD_LIST_ATTRIBUTES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_LIST_ATTRIBUTES))
#define GXML_IXSD_LIST_ATTRIBUTES_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_LIST_ATTRIBUTES, GXmlIXsdListAttributesIface))

typedef struct _GXmlIXsdListAttributes GXmlIXsdListAttributes;
typedef struct _GXmlIXsdListAttributesIface GXmlIXsdListAttributesIface;

#define GXML_TYPE_IXSD_LIST_ATTRIBUTES_GROUP (gxml_ixsd_list_attributes_group_get_type ())
#define GXML_IXSD_LIST_ATTRIBUTES_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_LIST_ATTRIBUTES_GROUP, GXmlIXsdListAttributesGroup))
#define GXML_IS_IXSD_LIST_ATTRIBUTES_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_LIST_ATTRIBUTES_GROUP))
#define GXML_IXSD_LIST_ATTRIBUTES_GROUP_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_LIST_ATTRIBUTES_GROUP, GXmlIXsdListAttributesGroupIface))

typedef struct _GXmlIXsdListAttributesGroup GXmlIXsdListAttributesGroup;
typedef struct _GXmlIXsdListAttributesGroupIface GXmlIXsdListAttributesGroupIface;

#define GXML_TYPE_IXSD_EXTENSION (gxml_ixsd_extension_get_type ())
#define GXML_IXSD_EXTENSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_EXTENSION, GXmlIXsdExtension))
#define GXML_IS_IXSD_EXTENSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_EXTENSION))
#define GXML_IXSD_EXTENSION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_EXTENSION, GXmlIXsdExtensionIface))

typedef struct _GXmlIXsdExtension GXmlIXsdExtension;
typedef struct _GXmlIXsdExtensionIface GXmlIXsdExtensionIface;

#define GXML_TYPE_IXSD_ELEMENT (gxml_ixsd_element_get_type ())
#define GXML_IXSD_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_ELEMENT, GXmlIXsdElement))
#define GXML_IS_IXSD_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_ELEMENT))
#define GXML_IXSD_ELEMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_ELEMENT, GXmlIXsdElementIface))

typedef struct _GXmlIXsdElement GXmlIXsdElement;
typedef struct _GXmlIXsdElementIface GXmlIXsdElementIface;

#define GXML_TYPE_IXSD_SIMPLE_CONTENT (gxml_ixsd_simple_content_get_type ())
#define GXML_IXSD_SIMPLE_CONTENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_SIMPLE_CONTENT, GXmlIXsdSimpleContent))
#define GXML_IS_IXSD_SIMPLE_CONTENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_SIMPLE_CONTENT))
#define GXML_IXSD_SIMPLE_CONTENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_SIMPLE_CONTENT, GXmlIXsdSimpleContentIface))

typedef struct _GXmlIXsdSimpleContent GXmlIXsdSimpleContent;
typedef struct _GXmlIXsdSimpleContentIface GXmlIXsdSimpleContentIface;

#define GXML_TYPE_IXSD_COMPLEX_CONTENT (gxml_ixsd_complex_content_get_type ())
#define GXML_IXSD_COMPLEX_CONTENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_COMPLEX_CONTENT, GXmlIXsdComplexContent))
#define GXML_IS_IXSD_COMPLEX_CONTENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_COMPLEX_CONTENT))
#define GXML_IXSD_COMPLEX_CONTENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_COMPLEX_CONTENT, GXmlIXsdComplexContentIface))

typedef struct _GXmlIXsdComplexContent GXmlIXsdComplexContent;
typedef struct _GXmlIXsdComplexContentIface GXmlIXsdComplexContentIface;

#define GXML_TYPE_IXSD_OPEN_CONTENT (gxml_ixsd_open_content_get_type ())
#define GXML_IXSD_OPEN_CONTENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_OPEN_CONTENT, GXmlIXsdOpenContent))
#define GXML_IS_IXSD_OPEN_CONTENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_OPEN_CONTENT))
#define GXML_IXSD_OPEN_CONTENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_OPEN_CONTENT, GXmlIXsdOpenContentIface))

typedef struct _GXmlIXsdOpenContent GXmlIXsdOpenContent;
typedef struct _GXmlIXsdOpenContentIface GXmlIXsdOpenContentIface;

#define GXML_TYPE_IXSD_BASE_ATTRIBUTE (gxml_ixsd_base_attribute_get_type ())
#define GXML_IXSD_BASE_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_BASE_ATTRIBUTE, GXmlIXsdBaseAttribute))
#define GXML_IS_IXSD_BASE_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_BASE_ATTRIBUTE))
#define GXML_IXSD_BASE_ATTRIBUTE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_BASE_ATTRIBUTE, GXmlIXsdBaseAttributeIface))

typedef struct _GXmlIXsdBaseAttribute GXmlIXsdBaseAttribute;
typedef struct _GXmlIXsdBaseAttributeIface GXmlIXsdBaseAttributeIface;

#define GXML_TYPE_IXSD_ATTRIBUTE (gxml_ixsd_attribute_get_type ())
#define GXML_IXSD_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_ATTRIBUTE, GXmlIXsdAttribute))
#define GXML_IS_IXSD_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_ATTRIBUTE))
#define GXML_IXSD_ATTRIBUTE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_ATTRIBUTE, GXmlIXsdAttributeIface))

typedef struct _GXmlIXsdAttribute GXmlIXsdAttribute;
typedef struct _GXmlIXsdAttributeIface GXmlIXsdAttributeIface;

#define GXML_TYPE_IXSD_ATTRIBUTE_GROUP (gxml_ixsd_attribute_group_get_type ())
#define GXML_IXSD_ATTRIBUTE_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_IXSD_ATTRIBUTE_GROUP, GXmlIXsdAttributeGroup))
#define GXML_IS_IXSD_ATTRIBUTE_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_IXSD_ATTRIBUTE_GROUP))
#define GXML_IXSD_ATTRIBUTE_GROUP_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_IXSD_ATTRIBUTE_GROUP, GXmlIXsdAttributeGroupIface))

typedef struct _GXmlIXsdAttributeGroup GXmlIXsdAttributeGroup;
typedef struct _GXmlIXsdAttributeGroupIface GXmlIXsdAttributeGroupIface;

typedef enum  {
	GXML_DOM_EVENT_PHASE_NONE = 0,
	GXML_DOM_EVENT_PHASE_CAPTURING_PHASE,
	GXML_DOM_EVENT_PHASE_AT_TARGET,
	GXML_DOM_EVENT_PHASE_BUBBLING_PHASE
} GXmlDomEventPhase;

struct _GXmlDomEventIface {
	GTypeInterface parent_iface;
	void (*stop_propagation) (GXmlDomEvent* self);
	void (*stop_immediate_propagation) (GXmlDomEvent* self);
	void (*prevent_default) (GXmlDomEvent* self);
	void (*init_event) (GXmlDomEvent* self, const gchar* type, gboolean bubbles, gboolean cancelable);
	const gchar* (*get_etype) (GXmlDomEvent* self);
	GXmlDomEventTarget* (*get_event_target) (GXmlDomEvent* self);
	GXmlDomEventTarget* (*get_current_target) (GXmlDomEvent* self);
	gboolean (*get_bubbles) (GXmlDomEvent* self);
	gboolean (*get_cancelable) (GXmlDomEvent* self);
	gboolean (*get_is_trusted) (GXmlDomEvent* self);
	GXmlDomTimeStamp* (*get_time_stamp) (GXmlDomEvent* self);
	gboolean (*get_default_prevented) (GXmlDomEvent* self);
	GXmlDomEventPhase (*get_event_phase) (GXmlDomEvent* self);
};

struct _GXmlDomEventListenerIface {
	GTypeInterface parent_iface;
	void (*handle_event) (GXmlDomEventListener* self, GXmlDomEvent* event);
};

struct _GXmlDomEventTargetIface {
	GTypeInterface parent_iface;
	void (*add_event_listener) (GXmlDomEventTarget* self, const gchar* type, GXmlDomEventListener* callback, gboolean capture);
	void (*remove_event_listener) (GXmlDomEventTarget* self, const gchar* type, GXmlDomEventListener* callback, gboolean capture);
	gboolean (*dispatch_event) (GXmlDomEventTarget* self, GXmlDomEvent* event, GError** error);
};

typedef enum  {
	GXML_DOM_NODE_DOCUMENT_POSITION_NONE = 1 << 0,
	GXML_DOM_NODE_DOCUMENT_POSITION_DISCONNECTED = 1 << 1,
	GXML_DOM_NODE_DOCUMENT_POSITION_PRECEDING = 1 << 2,
	GXML_DOM_NODE_DOCUMENT_POSITION_FOLLOWING = 1 << 3,
	GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINS = 1 << 4,
	GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINED_BY = 1 << 5,
	GXML_DOM_NODE_DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC = 1 << 6
} GXmlDomNodeDocumentPosition;

typedef enum  {
	GXML_DOM_NODE_NODE_TYPE_INVALID = 0,
	GXML_DOM_NODE_NODE_TYPE_ELEMENT_NODE = 1,
	GXML_DOM_NODE_NODE_TYPE_ATTRIBUTE_NODE,
	GXML_DOM_NODE_NODE_TYPE_TEXT_NODE,
	GXML_DOM_NODE_NODE_TYPE_CDATA_SECTION_NODE,
	GXML_DOM_NODE_NODE_TYPE_ENTITY_REFERENCE_NODE,
	GXML_DOM_NODE_NODE_TYPE_ENTITY_NODE,
	GXML_DOM_NODE_NODE_TYPE_PROCESSING_INSTRUCTION_NODE,
	GXML_DOM_NODE_NODE_TYPE_COMMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_TYPE_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_FRAGMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_NOTATION_NODE
} GXmlDomNodeNodeType;

struct _GXmlDomNodeListIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*item) (GXmlDomNodeList* self, gint index);
	gint (*get_length) (GXmlDomNodeList* self);
};

struct _GXmlDomHTMLCollectionIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_element) (GXmlDomHTMLCollection* self, gint index);
	GXmlDomElement** (*to_array) (GXmlDomHTMLCollection* self, int* result_length1);
	GXmlDomElement* (*item) (GXmlDomHTMLCollection* self, gint index);
	GXmlDomElement* (*named_item) (GXmlDomHTMLCollection* self, const gchar* name);
	gint (*get_length) (GXmlDomHTMLCollection* self);
};

struct _GXmlDomParentNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*query_selector) (GXmlDomParentNode* self, const gchar* selectors, GError** error);
	GXmlDomNodeList* (*query_selector_all) (GXmlDomParentNode* self, const gchar* selectors, GError** error);
	GXmlDomElementList* (*get_elements_by_property_value) (GXmlDomParentNode* self, const gchar* property, const gchar* value);
	GXmlDomHTMLCollection* (*get_children) (GXmlDomParentNode* self);
	GXmlDomElement* (*get_first_element_child) (GXmlDomParentNode* self);
	GXmlDomElement* (*get_last_element_child) (GXmlDomParentNode* self);
	gint (*get_child_element_count) (GXmlDomParentNode* self);
};

struct _GXmlDomNonElementParentNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_element_by_id) (GXmlDomNonElementParentNode* self, const gchar* element_id, GError** error);
};

struct _GXmlDomDocumentFragmentIface {
	GTypeInterface parent_iface;
};

struct _GXmlDomNonDocumentTypeChildNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_previous_element_sibling) (GXmlDomNonDocumentTypeChildNode* self);
	GXmlDomElement* (*get_next_element_sibling) (GXmlDomNonDocumentTypeChildNode* self);
};

struct _GXmlDomChildNodeIface {
	GTypeInterface parent_iface;
	void (*remove) (GXmlDomChildNode* self);
};

struct _GXmlDomCharacterDataIface {
	GTypeInterface parent_iface;
	gchar* (*substring_data) (GXmlDomCharacterData* self, gint offset, gint count, GError** error);
	void (*append_data) (GXmlDomCharacterData* self, const gchar* data);
	void (*insert_data) (GXmlDomCharacterData* self, gint offset, const gchar* data, GError** error);
	void (*delete_data) (GXmlDomCharacterData* self, gint offset, gint count, GError** error);
	void (*replace_data) (GXmlDomCharacterData* self, gint offset, gint count, const gchar* data, GError** error);
	gchar* (*get_data) (GXmlDomCharacterData* self);
	void (*set_data) (GXmlDomCharacterData* self, const gchar* value);
	gint (*get_length) (GXmlDomCharacterData* self);
};

struct _GXmlDomTextIface {
	GTypeInterface parent_iface;
	GXmlDomText* (*split_text) (GXmlDomText* self, gint offset, GError** error);
	gchar* (*get_whole_text) (GXmlDomText* self);
};

struct _GXmlDomCommentIface {
	GTypeInterface parent_iface;
};

struct _GXmlDomProcessingInstructionIface {
	GTypeInterface parent_iface;
	gchar* (*get_target) (GXmlDomProcessingInstruction* self);
};

typedef enum  {
	GXML_DOM_RANGE_BOUNDARY_POINTS_START_TO_START = 0,
	GXML_DOM_RANGE_BOUNDARY_POINTS_START_TO_END,
	GXML_DOM_RANGE_BOUNDARY_POINTS_END_TO_END,
	GXML_DOM_RANGE_BOUNDARY_POINTS_END_TO_START
} GXmlDomRangeBoundaryPoints;

struct _GXmlDomRangeIface {
	GTypeInterface parent_iface;
	void (*set_start) (GXmlDomRange* self, GXmlDomNode* node, gint offset, GError** error);
	void (*set_end) (GXmlDomRange* self, GXmlDomNode* node, gint offset, GError** error);
	void (*set_start_before) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_start_after) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_end_before) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_end_after) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*collapse) (GXmlDomRange* self, gboolean to_start, GError** error);
	void (*select_node) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*select_node_contents) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	gint (*compare_boundary_points) (GXmlDomRange* self, GXmlDomRangeBoundaryPoints how, GXmlDomRange* sourceRange, GError** error);
	void (*delete_contents) (GXmlDomRange* self, GError** error);
	GXmlDomDocumentFragment* (*extract_contents) (GXmlDomRange* self, GError** error);
	GXmlDomDocumentFragment* (*clone_contents) (GXmlDomRange* self, GError** error);
	void (*insert_node) (GXmlDomRange* self, GXmlDomNode* node);
	void (*surround_contents) (GXmlDomRange* self, GXmlDomNode* newParent);
	GXmlDomRange* (*clone_range) (GXmlDomRange* self);
	void (*detach) (GXmlDomRange* self);
	gboolean (*is_point_in_range) (GXmlDomRange* self, GXmlDomNode* node, gint offset);
	gshort (*compare_point) (GXmlDomRange* self, GXmlDomNode* node, gint offset);
	gboolean (*intersects_node) (GXmlDomRange* self, GXmlDomNode* node);
	gchar* (*to_string) (GXmlDomRange* self);
	GXmlDomNode* (*get_start_container) (GXmlDomRange* self);
	gint (*get_start_offset) (GXmlDomRange* self);
	GXmlDomNode* (*get_end_container) (GXmlDomRange* self);
	gint (*get_end_offset) (GXmlDomRange* self);
	gboolean (*get_collapsed) (GXmlDomRange* self);
	GXmlDomNode* (*get_common_ancestor_container) (GXmlDomRange* self);
};

struct _GXmlDomNodeIteratorIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*next_node) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*previous_node) (GXmlDomNodeIterator* self);
	void (*detach) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*get_root) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*get_reference_node) (GXmlDomNodeIterator* self);
	gboolean (*get_pointer_before_reference_node) (GXmlDomNodeIterator* self);
	gint (*get_what_to_show) (GXmlDomNodeIterator* self);
	GXmlDomNodeFilter* (*get_filter) (GXmlDomNodeIterator* self);
};

struct _GXmlDomTreeWalkerIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*parentNode) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*firstChild) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*lastChild) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*previousSibling) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*nextSibling) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*previousNode) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*nextNode) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*get_root) (GXmlDomTreeWalker* self);
	gint (*get_what_to_show) (GXmlDomTreeWalker* self);
	GXmlDomNodeFilter* (*get_filter) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*get_current_node) (GXmlDomTreeWalker* self);
};

struct _GXmlDomDocumentTypeIface {
	GTypeInterface parent_iface;
	const gchar* (*get_name) (GXmlDomDocumentType* self);
	const gchar* (*get_public_id) (GXmlDomDocumentType* self);
	const gchar* (*get_system_id) (GXmlDomDocumentType* self);
};

struct _GXmlDomXMLDocumentIface {
	GTypeInterface parent_iface;
};

struct _GXmlNamespaceIface {
	GTypeInterface parent_iface;
	gchar* (*get_uri) (GXmlNamespace* self);
	gchar* (*get_prefix) (GXmlNamespace* self);
};

typedef enum  {
	GXML_NODE_TYPE_INVALID = 0,
	GXML_NODE_TYPE_ELEMENT = 1,
	GXML_NODE_TYPE_ATTRIBUTE,
	GXML_NODE_TYPE_TEXT,
	GXML_NODE_TYPE_CDATA_SECTION,
	GXML_NODE_TYPE_ENTITY_REFERENCE,
	GXML_NODE_TYPE_ENTITY,
	GXML_NODE_TYPE_PROCESSING_INSTRUCTION,
	GXML_NODE_TYPE_COMMENT,
	GXML_NODE_TYPE_DOCUMENT,
	GXML_NODE_TYPE_DOCUMENT_TYPE,
	GXML_NODE_TYPE_DOCUMENT_FRAGMENT,
	GXML_NODE_TYPE_NOTATION
} GXmlNodeType;

struct _GXmlNodeIface {
	GTypeInterface parent_iface;
	GXmlNode* (*get) (GXmlNode* self, const gchar* key);
	GXmlElementList* (*get_elements_by_property_value) (GXmlNode* self, const gchar* property, const gchar* value);
	GXmlElementList* (*get_elements_by_name) (GXmlNode* self, const gchar* name);
	GXmlElementList* (*get_elements_by_name_ns) (GXmlNode* self, const gchar* name, const gchar* ns);
	gchar* (*to_string) (GXmlNode* self);
	gboolean (*set_namespace) (GXmlNode* self, const gchar* uri, const gchar* prefix);
	gchar* (*ns_prefix) (GXmlNode* self);
	gchar* (*ns_uri) (GXmlNode* self);
	GeeList* (*get_namespaces) (GXmlNode* self);
	GeeBidirList* (*get_children_nodes) (GXmlNode* self);
	GeeMap* (*get_attrs) (GXmlNode* self);
	gchar* (*get_name) (GXmlNode* self);
	gchar* (*get_value) (GXmlNode* self);
	void (*set_value) (GXmlNode* self, const gchar* value);
	GXmlNodeType (*get_type_node) (GXmlNode* self);
	GXmlDocument* (*get_document) (GXmlNode* self);
	GXmlNode* (*get_parent) (GXmlNode* self);
};

struct _GXmlDocumentIface {
	GTypeInterface parent_iface;
	GXmlNode* (*create_element) (GXmlDocument* self, const gchar* name, GError** error);
	GXmlNode* (*create_text) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_comment) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_cdata) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_pi) (GXmlDocument* self, const gchar* target, const gchar* data);
	gboolean (*save) (GXmlDocument* self, GCancellable* cancellable, GError** error);
	gboolean (*save_as) (GXmlDocument* self, GFile* f, GCancellable* cancellable, GError** error);
	gboolean (*get_indent) (GXmlDocument* self);
	void (*set_indent) (GXmlDocument* self, gboolean value);
	gboolean (*get_ns_top) (GXmlDocument* self);
	void (*set_ns_top) (GXmlDocument* self, gboolean value);
	gboolean (*get_prefix_default_ns) (GXmlDocument* self);
	void (*set_prefix_default_ns) (GXmlDocument* self, gboolean value);
	gboolean (*get_backup) (GXmlDocument* self);
	void (*set_backup) (GXmlDocument* self, gboolean value);
	GXmlNode* (*get_root) (GXmlDocument* self);
	GFile* (*get_file) (GXmlDocument* self);
	void (*set_file) (GXmlDocument* self, GFile* value);
};

struct _GXmlDomImplementationIface {
	GTypeInterface parent_iface;
	GXmlDomDocumentType* (*create_document_type) (GXmlDomImplementation* self, const gchar* qualified_name, const gchar* public_id, const gchar* system_id, GError** error);
	GXmlDomXMLDocument* (*create_document) (GXmlDomImplementation* self, const gchar* nspace, const gchar* qualified_name, GXmlDomDocumentType* doctype, GError** error);
	GXmlDocument* (*create_html_document) (GXmlDomImplementation* self, const gchar* title);
	gboolean (*has_feature) (GXmlDomImplementation* self);
};

struct _GXmlDomDocumentIface {
	GTypeInterface parent_iface;
	GXmlDomHTMLCollection* (*get_elements_by_tag_name) (GXmlDomDocument* self, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name_ns) (GXmlDomDocument* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_class_name) (GXmlDomDocument* self, const gchar* classNames);
	GXmlDomElement* (*create_element) (GXmlDomDocument* self, const gchar* local_name, GError** error);
	GXmlDomElement* (*create_element_ns) (GXmlDomDocument* self, const gchar* namespace, const gchar* qualified_name, GError** error);
	GXmlDomDocumentFragment* (*create_document_fragment) (GXmlDomDocument* self);
	GXmlDomText* (*create_text_node) (GXmlDomDocument* self, const gchar* data, GError** error);
	GXmlDomComment* (*create_comment) (GXmlDomDocument* self, const gchar* data, GError** error);
	GXmlDomProcessingInstruction* (*create_processing_instruction) (GXmlDomDocument* self, const gchar* target, const gchar* data, GError** error);
	GXmlDomNode* (*import_node) (GXmlDomDocument* self, GXmlDomNode* node, gboolean deep, GError** error);
	GXmlDomNode* (*adopt_node) (GXmlDomDocument* self, GXmlDomNode* node, GError** error);
	GXmlDomEvent* (*create_event) (GXmlDomDocument* self, const gchar* interface, GError** error);
	GXmlDomRange* (*create_range) (GXmlDomDocument* self);
	GXmlDomNodeIterator* (*create_node_iterator) (GXmlDomDocument* self, GXmlDomNode* root, gint whatToShow, GXmlDomNodeFilter* filter);
	GXmlDomTreeWalker* (*create_tree_walker) (GXmlDomDocument* self, GXmlDomNode* root, gint what_to_show, GXmlDomNodeFilter* filter);
	GXmlDomImplementation* (*get_implementation) (GXmlDomDocument* self);
	const gchar* (*get_url) (GXmlDomDocument* self);
	const gchar* (*get_document_uri) (GXmlDomDocument* self);
	const gchar* (*get_origin) (GXmlDomDocument* self);
	const gchar* (*get_compat_mode) (GXmlDomDocument* self);
	const gchar* (*get_character_set) (GXmlDomDocument* self);
	const gchar* (*get_content_type) (GXmlDomDocument* self);
	GXmlDomDocumentType* (*get_doctype) (GXmlDomDocument* self);
	GXmlDomElement* (*get_document_element) (GXmlDomDocument* self);
};

struct _GXmlDomNodeIface {
	GTypeInterface parent_iface;
	gboolean (*has_child_nodes) (GXmlDomNode* self);
	void (*normalize) (GXmlDomNode* self);
	gboolean (*is_equal_node) (GXmlDomNode* self, GXmlDomNode* node);
	GXmlDomNodeDocumentPosition (*compare_document_position) (GXmlDomNode* self, GXmlDomNode* other);
	gboolean (*contains) (GXmlDomNode* self, GXmlDomNode* other);
	gchar* (*lookup_prefix) (GXmlDomNode* self, const gchar* nspace);
	gchar* (*lookup_namespace_uri) (GXmlDomNode* self, const gchar* prefix);
	gboolean (*is_default_namespace) (GXmlDomNode* self, const gchar* nspace);
	GXmlDomNode* (*insert_before) (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*append_child) (GXmlDomNode* self, GXmlDomNode* node, GError** error);
	GXmlDomNode* (*replace_child) (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*remove_child) (GXmlDomNode* self, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*clone_node) (GXmlDomNode* self, gboolean deep, GError** error);
	GXmlDomNodeNodeType (*get_node_type) (GXmlDomNode* self);
	gchar* (*get_node_name) (GXmlDomNode* self);
	const gchar* (*get_base_uri) (GXmlDomNode* self);
	GXmlDomDocument* (*get_owner_document) (GXmlDomNode* self);
	void (*set_owner_document) (GXmlDomNode* self, GXmlDomDocument* value);
	GXmlDomNode* (*get_parent_node) (GXmlDomNode* self);
	GXmlDomElement* (*get_parent_element) (GXmlDomNode* self);
	GXmlDomNodeList* (*get_child_nodes) (GXmlDomNode* self);
	GXmlDomNode* (*get_first_child) (GXmlDomNode* self);
	GXmlDomNode* (*get_last_child) (GXmlDomNode* self);
	GXmlDomNode* (*get_previous_sibling) (GXmlDomNode* self);
	GXmlDomNode* (*get_next_sibling) (GXmlDomNode* self);
	gchar* (*get_node_value) (GXmlDomNode* self);
	void (*set_node_value) (GXmlDomNode* self, const gchar* value);
	gchar* (*get_text_content) (GXmlDomNode* self);
	void (*set_text_content) (GXmlDomNode* self, const gchar* value);
};

struct _GXmlDomTokenListIface {
	GTypeInterface parent_iface;
	gchar* (*item) (GXmlDomTokenList* self, gint index);
	gboolean (*contains) (GXmlDomTokenList* self, const gchar* token, GError** error);
	void (*add) (GXmlDomTokenList* self, gchar** tokens, int tokens_length1, GError** error);
	void (*remove) (GXmlDomTokenList* self, gchar** tokens, int tokens_length1);
	gboolean (*toggle) (GXmlDomTokenList* self, const gchar* token, gboolean force, gboolean _auto_, GError** error);
	gchar* (*to_string) (GXmlDomTokenList* self);
	gint (*get_length) (GXmlDomTokenList* self);
};

struct _GXmlDomNamedNodeMapIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*item) (GXmlDomNamedNodeMap* self, gint index);
	GXmlDomNode* (*get_named_item) (GXmlDomNamedNodeMap* self, const gchar* name);
	GXmlDomNode* (*set_named_item) (GXmlDomNamedNodeMap* self, GXmlDomNode* node, GError** error);
	GXmlDomNode* (*remove_named_item) (GXmlDomNamedNodeMap* self, const gchar* name, GError** error);
	GXmlDomNode* (*remove_named_item_ns) (GXmlDomNamedNodeMap* self, const gchar* namespace_uri, const gchar* localName, GError** error);
	GXmlDomNode* (*get_named_item_ns) (GXmlDomNamedNodeMap* self, const gchar* namespace_uri, const gchar* local_name, GError** error);
	GXmlDomNode* (*set_named_item_ns) (GXmlDomNamedNodeMap* self, GXmlDomNode* node, GError** error);
	gint (*get_length) (GXmlDomNamedNodeMap* self);
};

struct _GXmlDomElementIface {
	GTypeInterface parent_iface;
	gchar* (*get_attribute) (GXmlDomElement* self, const gchar* name);
	gchar* (*get_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	void (*set_attribute) (GXmlDomElement* self, const gchar* name, const gchar* value, GError** error);
	void (*set_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* name, const gchar* value, GError** error);
	void (*remove_attribute) (GXmlDomElement* self, const gchar* name);
	void (*remove_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	gboolean (*has_attribute) (GXmlDomElement* self, const gchar* name);
	gboolean (*has_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name) (GXmlDomElement* self, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_class_name) (GXmlDomElement* self, const gchar* class_names);
	gchar* (*get_namespace_uri) (GXmlDomElement* self);
	gchar* (*get_prefix) (GXmlDomElement* self);
	gchar* (*get_local_name) (GXmlDomElement* self);
	gchar* (*get_tag_name) (GXmlDomElement* self);
	gchar* (*get_id) (GXmlDomElement* self);
	void (*set_id) (GXmlDomElement* self, const gchar* value);
	gchar* (*get_class_name) (GXmlDomElement* self);
	void (*set_class_name) (GXmlDomElement* self, const gchar* value);
	GXmlDomTokenList* (*get_class_list) (GXmlDomElement* self);
	GXmlDomNamedNodeMap* (*get_attributes) (GXmlDomElement* self);
};

struct _GXmlGomCollectionIface {
	GTypeInterface parent_iface;
	void (*search) (GXmlGomCollection* self, GError** error);
	GXmlDomElement* (*get_item) (GXmlGomCollection* self, gint index, GError** error);
	void (*append) (GXmlGomCollection* self, GXmlDomElement* node, GError** error);
	void (*initialize) (GXmlGomCollection* self, GType t, GError** error);
	GXmlGomElement* (*create_item) (GXmlGomCollection* self);
	gboolean (*validate_append) (GXmlGomCollection* self, gint index, GXmlDomElement* element, GError** error);
	GQueue* (*get_nodes_index) (GXmlGomCollection* self);
	GXmlGomElement* (*get_element) (GXmlGomCollection* self);
	void (*set_element) (GXmlGomCollection* self, GXmlGomElement* value);
	const gchar* (*get_items_name) (GXmlGomCollection* self);
	GType (*get_items_type) (GXmlGomCollection* self);
	void (*set_items_type) (GXmlGomCollection* self, GType value);
	gint (*get_length) (GXmlGomCollection* self);
};

struct _GXmlIXsdListIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_item) (GXmlIXsdList* self, gint index);
	void (*append) (GXmlIXsdList* self, GXmlDomElement* element);
	void (*remove) (GXmlIXsdList* self, gint index);
	gint (*index_of) (GXmlIXsdList* self, GXmlDomElement* element);
	GXmlDomElement* (*get_element) (GXmlIXsdList* self);
	void (*set_element) (GXmlIXsdList* self, GXmlDomElement* value);
	GType (*get_items_type) (GXmlIXsdList* self);
	void (*set_items_type) (GXmlIXsdList* self, GType value);
	GType (*get_items_name) (GXmlIXsdList* self);
	void (*set_items_name) (GXmlIXsdList* self, GType value);
	gint (*get_length) (GXmlIXsdList* self);
};

struct _GXmlIXsdListElementsIface {
	GTypeInterface parent_iface;
};

struct _GXmlIXsdListSimpleTypesIface {
	GTypeInterface parent_iface;
};

struct _GXmlIXsdListComplexTypesIface {
	GTypeInterface parent_iface;
};

struct _GXmlIXsdSchemaIface {
	GTypeInterface parent_iface;
	GXmlIXsdListElements* (*get_element_definitions) (GXmlIXsdSchema* self);
	void (*set_element_definitions) (GXmlIXsdSchema* self, GXmlIXsdListElements* value);
	GXmlIXsdListSimpleTypes* (*get_simple_type_definitions) (GXmlIXsdSchema* self);
	void (*set_simple_type_definitions) (GXmlIXsdSchema* self, GXmlIXsdListSimpleTypes* value);
	GXmlIXsdListComplexTypes* (*get_complex_type_definitions) (GXmlIXsdSchema* self);
	void (*set_complex_type_definitions) (GXmlIXsdSchema* self, GXmlIXsdListComplexTypes* value);
};

typedef enum  {
	GXML_IXSD_SCHEMA_ERROR_INVALIDATION_ERROR
} GXmlIXsdSchemaError;
#define GXML_IXSD_SCHEMA_ERROR gxml_ixsd_schema_error_quark ()
struct _GXmlIXsdAnnotationIface {
	GTypeInterface parent_iface;
};

struct _GXmlIXsdBaseTypeIface {
	GTypeInterface parent_iface;
	GXmlIXsdAnnotation* (*get_anotation) (GXmlIXsdBaseType* self);
	void (*set_anotation) (GXmlIXsdBaseType* self, GXmlIXsdAnnotation* value);
};

struct _GXmlIXsdTypeDefIface {
	GTypeInterface parent_iface;
};

struct _GXmlIXsdTypeListIface {
	GTypeInterface parent_iface;
};

struct _GXmlIXsdTypeUnionIface {
	GTypeInterface parent_iface;
};

struct _GXmlIXsdListTypeRestrictionEnumerationsIface {
	GTypeInterface parent_iface;
};

struct _GXmlIXsdListTypeRestrictionWhiteSpacesIface {
	GTypeInterface parent_iface;
};

struct _GXmlIXsdTypeRestrictionIface {
	GTypeInterface parent_iface;
	const gchar* (*get_base) (GXmlIXsdTypeRestriction* self);
	void (*set_base) (GXmlIXsdTypeRestriction* self, const gchar* value);
	const gchar* (*get_id) (GXmlIXsdTypeRestriction* self);
	void (*set_id) (GXmlIXsdTypeRestriction* self, const gchar* value);
	GXmlIXsdSimpleType* (*get_simple_type) (GXmlIXsdTypeRestriction* self);
	void (*set_simple_type) (GXmlIXsdTypeRestriction* self, GXmlIXsdSimpleType* value);
	GXmlIXsdListTypeRestrictionEnumerations* (*get_enumerations) (GXmlIXsdTypeRestriction* self);
	void (*set_enumerations) (GXmlIXsdTypeRestriction* self, GXmlIXsdListTypeRestrictionEnumerations* value);
	GXmlIXsdListTypeRestrictionWhiteSpaces* (*get_white_spaces) (GXmlIXsdTypeRestriction* self);
	void (*set_white_spaces) (GXmlIXsdTypeRestriction* self, GXmlIXsdListTypeRestrictionWhiteSpaces* value);
};

struct _GXmlIXsdSimpleTypeIface {
	GTypeInterface parent_iface;
	const gchar* (*get_final) (GXmlIXsdSimpleType* self);
	void (*set_final) (GXmlIXsdSimpleType* self, const gchar* value);
	const gchar* (*get_id) (GXmlIXsdSimpleType* self);
	void (*set_id) (GXmlIXsdSimpleType* self, const gchar* value);
	const gchar* (*get_name) (GXmlIXsdSimpleType* self);
	void (*set_name) (GXmlIXsdSimpleType* self, const gchar* value);
	GXmlIXsdAnnotation* (*get_annotation) (GXmlIXsdSimpleType* self);
	void (*set_annotation) (GXmlIXsdSimpleType* self, GXmlIXsdAnnotation* value);
	GXmlIXsdTypeList* (*get_list) (GXmlIXsdSimpleType* self);
	void (*set_list) (GXmlIXsdSimpleType* self, GXmlIXsdTypeList* value);
	GXmlIXsdTypeUnion* (*get_union) (GXmlIXsdSimpleType* self);
	void (*set_union) (GXmlIXsdSimpleType* self, GXmlIXsdTypeUnion* value);
	GXmlIXsdTypeRestriction* (*get_restriction) (GXmlIXsdSimpleType* self);
	void (*set_restriction) (GXmlIXsdSimpleType* self, GXmlIXsdTypeRestriction* value);
};

struct _GXmlIXsdTypeRestrictionDefIface {
	GTypeInterface parent_iface;
	GXmlIXsdAnnotation* (*get_annotation) (GXmlIXsdTypeRestrictionDef* self);
	void (*set_annotation) (GXmlIXsdTypeRestrictionDef* self, GXmlIXsdAnnotation* value);
};

struct _GXmlIXsdTypeRestrictionMinExclusiveIface {
	GTypeInterface parent_iface;
};

struct _GXmlIXsdTypeRestrictionMinInclusiveIface {
	GTypeInterface parent_iface;
};

struct _GXmlIXsdTypeRestrictionMaxExclusiveIface {
	GTypeInterface parent_iface;
};

struct _GXmlIXsdTypeRestrictionMaxInclusiveIface {
	GTypeInterface parent_iface;
};

struct _GXmlIXsdTypeRestrictionTotalDigitsIface {
	GTypeInterface parent_iface;
};

struct _GXmlIXsdTypeRestrictionFractionDigitsIface {
	GTypeInterface parent_iface;
};

struct _GXmlIXsdTypeRestrictionLengthIface {
	GTypeInterface parent_iface;
};

struct _GXmlIXsdTypeRestrictionMinLengthIface {
	GTypeInterface parent_iface;
};

struct _GXmlIXsdTypeRestrictionMaxLengthIface {
	GTypeInterface parent_iface;
};

struct _GXmlIXsdTypeRestrictionEnumerationIface {
	GTypeInterface parent_iface;
	const gchar* (*get_id) (GXmlIXsdTypeRestrictionEnumeration* self);
	void (*set_id) (GXmlIXsdTypeRestrictionEnumeration* self, const gchar* value);
	const gchar* (*get_value) (GXmlIXsdTypeRestrictionEnumeration* self);
	void (*set_value) (GXmlIXsdTypeRestrictionEnumeration* self, const gchar* value);
};

struct _GXmlIXsdTypeRestrictionWhiteSpaceIface {
	GTypeInterface parent_iface;
	gboolean (*get_fixed) (GXmlIXsdTypeRestrictionWhiteSpace* self);
	void (*set_fixed) (GXmlIXsdTypeRestrictionWhiteSpace* self, gboolean value);
	const gchar* (*get_id) (GXmlIXsdTypeRestrictionWhiteSpace* self);
	void (*set_id) (GXmlIXsdTypeRestrictionWhiteSpace* self, const gchar* value);
	const gchar* (*get_value) (GXmlIXsdTypeRestrictionWhiteSpace* self);
	void (*set_value) (GXmlIXsdTypeRestrictionWhiteSpace* self, const gchar* value);
};

struct _GXmlIXsdTypeRestrictionPatternIface {
	GTypeInterface parent_iface;
};

struct _GXmlIXsdTypeRestrictionAssertionIface {
	GTypeInterface parent_iface;
};

struct _GXmlIXsdTypeRestrictionExplicitTimezoneIface {
	GTypeInterface parent_iface;
};

struct _GXmlIXsdBaseContentIface {
	GTypeInterface parent_iface;
	GXmlIXsdAnnotation* (*get_anotation) (GXmlIXsdBaseContent* self);
	void (*set_anotation) (GXmlIXsdBaseContent* self, GXmlIXsdAnnotation* value);
};

struct _GXmlIXsdListAttributesIface {
	GTypeInterface parent_iface;
};

struct _GXmlIXsdListAttributesGroupIface {
	GTypeInterface parent_iface;
};

struct _GXmlIXsdComplexTypeIface {
	GTypeInterface parent_iface;
	gboolean (*get_abstract) (GXmlIXsdComplexType* self);
	void (*set_abstract) (GXmlIXsdComplexType* self, gboolean value);
	const gchar* (*get_block) (GXmlIXsdComplexType* self);
	void (*set_block) (GXmlIXsdComplexType* self, const gchar* value);
	const gchar* (*get_final) (GXmlIXsdComplexType* self);
	void (*set_final) (GXmlIXsdComplexType* self, const gchar* value);
	gboolean (*get_mixed) (GXmlIXsdComplexType* self);
	void (*set_mixed) (GXmlIXsdComplexType* self, gboolean value);
	const gchar* (*get_name) (GXmlIXsdComplexType* self);
	void (*set_name) (GXmlIXsdComplexType* self, const gchar* value);
	gboolean (*get_default_attributes_apply) (GXmlIXsdComplexType* self);
	void (*set_default_attributes_apply) (GXmlIXsdComplexType* self, gboolean value);
	GXmlIXsdBaseContent* (*get_content_type) (GXmlIXsdComplexType* self);
	void (*set_content_type) (GXmlIXsdComplexType* self, GXmlIXsdBaseContent* value);
	GXmlIXsdListAttributes* (*get_type_attributes) (GXmlIXsdComplexType* self);
	GXmlIXsdListAttributesGroup* (*get_group_attributes) (GXmlIXsdComplexType* self);
};

struct _GXmlIXsdExtensionIface {
	GTypeInterface parent_iface;
	const gchar* (*get_base) (GXmlIXsdExtension* self);
	void (*set_base) (GXmlIXsdExtension* self, const gchar* value);
};

struct _GXmlIXsdElementIface {
	GTypeInterface parent_iface;
	gboolean (*get_abstract) (GXmlIXsdElement* self);
	void (*set_abstract) (GXmlIXsdElement* self, gboolean value);
	const gchar* (*get_block) (GXmlIXsdElement* self);
	void (*set_block) (GXmlIXsdElement* self, const gchar* value);
	const gchar* (*get_default) (GXmlIXsdElement* self);
	void (*set_default) (GXmlIXsdElement* self, const gchar* value);
	const gchar* (*get_final) (GXmlIXsdElement* self);
	void (*set_final) (GXmlIXsdElement* self, const gchar* value);
	const gchar* (*get_fixed) (GXmlIXsdElement* self);
	void (*set_fixed) (GXmlIXsdElement* self, const gchar* value);
	const gchar* (*get_form) (GXmlIXsdElement* self);
	void (*set_form) (GXmlIXsdElement* self, const gchar* value);
	const gchar* (*get_id) (GXmlIXsdElement* self);
	void (*set_id) (GXmlIXsdElement* self, const gchar* value);
	const gchar* (*get_maxOccurs) (GXmlIXsdElement* self);
	void (*set_maxOccurs) (GXmlIXsdElement* self, const gchar* value);
	const gchar* (*get_minOccurs) (GXmlIXsdElement* self);
	void (*set_minOccurs) (GXmlIXsdElement* self, const gchar* value);
	const gchar* (*get_name) (GXmlIXsdElement* self);
	void (*set_name) (GXmlIXsdElement* self, const gchar* value);
	gboolean (*get_nillable) (GXmlIXsdElement* self);
	void (*set_nillable) (GXmlIXsdElement* self, gboolean value);
	const gchar* (*get_ref) (GXmlIXsdElement* self);
	void (*set_ref) (GXmlIXsdElement* self, const gchar* value);
	GXmlDomTokenList* (*get_substitution_group) (GXmlIXsdElement* self);
	void (*set_substitution_group) (GXmlIXsdElement* self, GXmlDomTokenList* value);
	const gchar* (*get_target_namespace) (GXmlIXsdElement* self);
	void (*set_target_namespace) (GXmlIXsdElement* self, const gchar* value);
	const gchar* (*get_object_type) (GXmlIXsdElement* self);
	void (*set_object_type) (GXmlIXsdElement* self, const gchar* value);
	GXmlIXsdAnnotation* (*get_anotation) (GXmlIXsdElement* self);
	void (*set_anotation) (GXmlIXsdElement* self, GXmlIXsdAnnotation* value);
	GXmlIXsdSimpleType* (*get_simple_type) (GXmlIXsdElement* self);
	void (*set_simple_type) (GXmlIXsdElement* self, GXmlIXsdSimpleType* value);
	GXmlIXsdComplexType* (*get_complex_type) (GXmlIXsdElement* self);
	void (*set_complex_type) (GXmlIXsdElement* self, GXmlIXsdComplexType* value);
};

struct _GXmlIXsdSimpleContentIface {
	GTypeInterface parent_iface;
};

struct _GXmlIXsdComplexContentIface {
	GTypeInterface parent_iface;
};

struct _GXmlIXsdOpenContentIface {
	GTypeInterface parent_iface;
};

struct _GXmlIXsdBaseAttributeIface {
	GTypeInterface parent_iface;
	GXmlIXsdAnnotation* (*get_anotation) (GXmlIXsdBaseAttribute* self);
	void (*set_anotation) (GXmlIXsdBaseAttribute* self, GXmlIXsdAnnotation* value);
};

struct _GXmlIXsdAttributeIface {
	GTypeInterface parent_iface;
};

struct _GXmlIXsdAttributeGroupIface {
	GTypeInterface parent_iface;
};



GType gxml_dom_time_stamp_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_phase_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_listener_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_target_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_document_position_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_node_type_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_element_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_html_collection_get_type (void) G_GNUC_CONST;
GType gxml_dom_parent_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_non_element_parent_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_fragment_get_type (void) G_GNUC_CONST;
GType gxml_dom_non_document_type_child_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_child_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_character_data_get_type (void) G_GNUC_CONST;
GType gxml_dom_text_get_type (void) G_GNUC_CONST;
GType gxml_dom_comment_get_type (void) G_GNUC_CONST;
GType gxml_dom_processing_instruction_get_type (void) G_GNUC_CONST;
GType gxml_dom_range_boundary_points_get_type (void) G_GNUC_CONST;
GType gxml_dom_range_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_filter_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_iterator_get_type (void) G_GNUC_CONST;
GType gxml_dom_tree_walker_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_type_get_type (void) G_GNUC_CONST;
GType gxml_dom_xml_document_get_type (void) G_GNUC_CONST;
GType gxml_element_list_get_type (void) G_GNUC_CONST;
GType gxml_namespace_get_type (void) G_GNUC_CONST;
GType gxml_node_type_get_type (void) G_GNUC_CONST;
GType gxml_node_get_type (void) G_GNUC_CONST;
GType gxml_document_get_type (void) G_GNUC_CONST;
GType gxml_dom_implementation_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_token_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_named_node_map_get_type (void) G_GNUC_CONST;
GType gxml_dom_element_get_type (void) G_GNUC_CONST;
GType gxml_gom_node_get_type (void) G_GNUC_CONST;
GType gxml_gom_element_get_type (void) G_GNUC_CONST;
GType gxml_gom_collection_get_type (void) G_GNUC_CONST;
GType gxml_ixsd_list_get_type (void) G_GNUC_CONST;
GType gxml_ixsd_list_elements_get_type (void) G_GNUC_CONST;
GType gxml_ixsd_list_simple_types_get_type (void) G_GNUC_CONST;
GType gxml_ixsd_list_complex_types_get_type (void) G_GNUC_CONST;
GType gxml_ixsd_schema_get_type (void) G_GNUC_CONST;
#define GXML_IXSD_SCHEMA_SCHEMA_NODE_NAME "schema"
#define GXML_IXSD_SCHEMA_SCHEMA_NAMESPACE_URI "http://www.w3.org/2001/XMLSchema"
#define GXML_IXSD_SCHEMA_SCHEMA_NAMESPACE_PREFIX "xs"
GXmlIXsdListElements* gxml_ixsd_schema_get_element_definitions (GXmlIXsdSchema* self);
void gxml_ixsd_schema_set_element_definitions (GXmlIXsdSchema* self, GXmlIXsdListElements* value);
GXmlIXsdListSimpleTypes* gxml_ixsd_schema_get_simple_type_definitions (GXmlIXsdSchema* self);
void gxml_ixsd_schema_set_simple_type_definitions (GXmlIXsdSchema* self, GXmlIXsdListSimpleTypes* value);
GXmlIXsdListComplexTypes* gxml_ixsd_schema_get_complex_type_definitions (GXmlIXsdSchema* self);
void gxml_ixsd_schema_set_complex_type_definitions (GXmlIXsdSchema* self, GXmlIXsdListComplexTypes* value);
GQuark gxml_ixsd_schema_error_quark (void);
GType gxml_ixsd_annotation_get_type (void) G_GNUC_CONST;
GType gxml_ixsd_base_type_get_type (void) G_GNUC_CONST;
GXmlIXsdAnnotation* gxml_ixsd_base_type_get_anotation (GXmlIXsdBaseType* self);
void gxml_ixsd_base_type_set_anotation (GXmlIXsdBaseType* self, GXmlIXsdAnnotation* value);
GType gxml_ixsd_type_def_get_type (void) G_GNUC_CONST;
GType gxml_ixsd_type_list_get_type (void) G_GNUC_CONST;
GType gxml_ixsd_type_union_get_type (void) G_GNUC_CONST;
GType gxml_ixsd_list_type_restriction_enumerations_get_type (void) G_GNUC_CONST;
GType gxml_ixsd_list_type_restriction_white_spaces_get_type (void) G_GNUC_CONST;
GType gxml_ixsd_type_restriction_get_type (void) G_GNUC_CONST;
GType gxml_ixsd_simple_type_get_type (void) G_GNUC_CONST;
#define GXML_IXSD_SIMPLE_TYPE_SCHEMA_NODE_NAME "simpleType"
const gchar* gxml_ixsd_simple_type_get_final (GXmlIXsdSimpleType* self);
void gxml_ixsd_simple_type_set_final (GXmlIXsdSimpleType* self, const gchar* value);
const gchar* gxml_ixsd_simple_type_get_id (GXmlIXsdSimpleType* self);
void gxml_ixsd_simple_type_set_id (GXmlIXsdSimpleType* self, const gchar* value);
const gchar* gxml_ixsd_simple_type_get_name (GXmlIXsdSimpleType* self);
void gxml_ixsd_simple_type_set_name (GXmlIXsdSimpleType* self, const gchar* value);
GXmlIXsdAnnotation* gxml_ixsd_simple_type_get_annotation (GXmlIXsdSimpleType* self);
void gxml_ixsd_simple_type_set_annotation (GXmlIXsdSimpleType* self, GXmlIXsdAnnotation* value);
GXmlIXsdTypeList* gxml_ixsd_simple_type_get_list (GXmlIXsdSimpleType* self);
void gxml_ixsd_simple_type_set_list (GXmlIXsdSimpleType* self, GXmlIXsdTypeList* value);
GXmlIXsdTypeUnion* gxml_ixsd_simple_type_get_union (GXmlIXsdSimpleType* self);
void gxml_ixsd_simple_type_set_union (GXmlIXsdSimpleType* self, GXmlIXsdTypeUnion* value);
GXmlIXsdTypeRestriction* gxml_ixsd_simple_type_get_restriction (GXmlIXsdSimpleType* self);
void gxml_ixsd_simple_type_set_restriction (GXmlIXsdSimpleType* self, GXmlIXsdTypeRestriction* value);
#define GXML_IXSD_TYPE_RESTRICTION_SCHEMA_NODE_NAME "restriction"
const gchar* gxml_ixsd_type_restriction_get_base (GXmlIXsdTypeRestriction* self);
void gxml_ixsd_type_restriction_set_base (GXmlIXsdTypeRestriction* self, const gchar* value);
const gchar* gxml_ixsd_type_restriction_get_id (GXmlIXsdTypeRestriction* self);
void gxml_ixsd_type_restriction_set_id (GXmlIXsdTypeRestriction* self, const gchar* value);
GXmlIXsdSimpleType* gxml_ixsd_type_restriction_get_simple_type (GXmlIXsdTypeRestriction* self);
void gxml_ixsd_type_restriction_set_simple_type (GXmlIXsdTypeRestriction* self, GXmlIXsdSimpleType* value);
GXmlIXsdListTypeRestrictionEnumerations* gxml_ixsd_type_restriction_get_enumerations (GXmlIXsdTypeRestriction* self);
void gxml_ixsd_type_restriction_set_enumerations (GXmlIXsdTypeRestriction* self, GXmlIXsdListTypeRestrictionEnumerations* value);
GXmlIXsdListTypeRestrictionWhiteSpaces* gxml_ixsd_type_restriction_get_white_spaces (GXmlIXsdTypeRestriction* self);
void gxml_ixsd_type_restriction_set_white_spaces (GXmlIXsdTypeRestriction* self, GXmlIXsdListTypeRestrictionWhiteSpaces* value);
GType gxml_ixsd_type_restriction_def_get_type (void) G_GNUC_CONST;
GXmlIXsdAnnotation* gxml_ixsd_type_restriction_def_get_annotation (GXmlIXsdTypeRestrictionDef* self);
void gxml_ixsd_type_restriction_def_set_annotation (GXmlIXsdTypeRestrictionDef* self, GXmlIXsdAnnotation* value);
GType gxml_ixsd_type_restriction_min_exclusive_get_type (void) G_GNUC_CONST;
GType gxml_ixsd_type_restriction_min_inclusive_get_type (void) G_GNUC_CONST;
GType gxml_ixsd_type_restriction_max_exclusive_get_type (void) G_GNUC_CONST;
GType gxml_ixsd_type_restriction_max_inclusive_get_type (void) G_GNUC_CONST;
GType gxml_ixsd_type_restriction_total_digits_get_type (void) G_GNUC_CONST;
GType gxml_ixsd_type_restriction_fraction_digits_get_type (void) G_GNUC_CONST;
GType gxml_ixsd_type_restriction_length_get_type (void) G_GNUC_CONST;
GType gxml_ixsd_type_restriction_min_length_get_type (void) G_GNUC_CONST;
GType gxml_ixsd_type_restriction_max_length_get_type (void) G_GNUC_CONST;
GType gxml_ixsd_type_restriction_enumeration_get_type (void) G_GNUC_CONST;
#define GXML_IXSD_TYPE_RESTRICTION_ENUMERATION_SCHEMA_NODE_NAME "enumeration"
const gchar* gxml_ixsd_type_restriction_enumeration_get_id (GXmlIXsdTypeRestrictionEnumeration* self);
void gxml_ixsd_type_restriction_enumeration_set_id (GXmlIXsdTypeRestrictionEnumeration* self, const gchar* value);
const gchar* gxml_ixsd_type_restriction_enumeration_get_value (GXmlIXsdTypeRestrictionEnumeration* self);
void gxml_ixsd_type_restriction_enumeration_set_value (GXmlIXsdTypeRestrictionEnumeration* self, const gchar* value);
GType gxml_ixsd_type_restriction_white_space_get_type (void) G_GNUC_CONST;
#define GXML_IXSD_TYPE_RESTRICTION_WHITE_SPACE_SCHEMA_NODE_NAME "whiteSpace"
gboolean gxml_ixsd_type_restriction_white_space_get_fixed (GXmlIXsdTypeRestrictionWhiteSpace* self);
void gxml_ixsd_type_restriction_white_space_set_fixed (GXmlIXsdTypeRestrictionWhiteSpace* self, gboolean value);
const gchar* gxml_ixsd_type_restriction_white_space_get_id (GXmlIXsdTypeRestrictionWhiteSpace* self);
void gxml_ixsd_type_restriction_white_space_set_id (GXmlIXsdTypeRestrictionWhiteSpace* self, const gchar* value);
const gchar* gxml_ixsd_type_restriction_white_space_get_value (GXmlIXsdTypeRestrictionWhiteSpace* self);
void gxml_ixsd_type_restriction_white_space_set_value (GXmlIXsdTypeRestrictionWhiteSpace* self, const gchar* value);
GType gxml_ixsd_type_restriction_pattern_get_type (void) G_GNUC_CONST;
GType gxml_ixsd_type_restriction_assertion_get_type (void) G_GNUC_CONST;
GType gxml_ixsd_type_restriction_explicit_timezone_get_type (void) G_GNUC_CONST;
GType gxml_ixsd_base_content_get_type (void) G_GNUC_CONST;
GType gxml_ixsd_list_attributes_get_type (void) G_GNUC_CONST;
GType gxml_ixsd_list_attributes_group_get_type (void) G_GNUC_CONST;
GType gxml_ixsd_complex_type_get_type (void) G_GNUC_CONST;
#define GXML_IXSD_COMPLEX_TYPE_SCHEMA_NODE_NAME "complexType"
gboolean gxml_ixsd_complex_type_get_abstract (GXmlIXsdComplexType* self);
void gxml_ixsd_complex_type_set_abstract (GXmlIXsdComplexType* self, gboolean value);
const gchar* gxml_ixsd_complex_type_get_block (GXmlIXsdComplexType* self);
void gxml_ixsd_complex_type_set_block (GXmlIXsdComplexType* self, const gchar* value);
const gchar* gxml_ixsd_complex_type_get_final (GXmlIXsdComplexType* self);
void gxml_ixsd_complex_type_set_final (GXmlIXsdComplexType* self, const gchar* value);
gboolean gxml_ixsd_complex_type_get_mixed (GXmlIXsdComplexType* self);
void gxml_ixsd_complex_type_set_mixed (GXmlIXsdComplexType* self, gboolean value);
const gchar* gxml_ixsd_complex_type_get_name (GXmlIXsdComplexType* self);
void gxml_ixsd_complex_type_set_name (GXmlIXsdComplexType* self, const gchar* value);
gboolean gxml_ixsd_complex_type_get_default_attributes_apply (GXmlIXsdComplexType* self);
void gxml_ixsd_complex_type_set_default_attributes_apply (GXmlIXsdComplexType* self, gboolean value);
GXmlIXsdBaseContent* gxml_ixsd_complex_type_get_content_type (GXmlIXsdComplexType* self);
void gxml_ixsd_complex_type_set_content_type (GXmlIXsdComplexType* self, GXmlIXsdBaseContent* value);
GXmlIXsdListAttributes* gxml_ixsd_complex_type_get_type_attributes (GXmlIXsdComplexType* self);
GXmlIXsdListAttributesGroup* gxml_ixsd_complex_type_get_group_attributes (GXmlIXsdComplexType* self);
GType gxml_ixsd_extension_get_type (void) G_GNUC_CONST;
#define GXML_IXSD_EXTENSION_SCHEMA_NODE_NAME "extension"
const gchar* gxml_ixsd_extension_get_base (GXmlIXsdExtension* self);
void gxml_ixsd_extension_set_base (GXmlIXsdExtension* self, const gchar* value);
GType gxml_ixsd_element_get_type (void) G_GNUC_CONST;
#define GXML_IXSD_ELEMENT_SCHEMA_NODE_NAME "element"
gboolean gxml_ixsd_element_get_abstract (GXmlIXsdElement* self);
void gxml_ixsd_element_set_abstract (GXmlIXsdElement* self, gboolean value);
const gchar* gxml_ixsd_element_get_block (GXmlIXsdElement* self);
void gxml_ixsd_element_set_block (GXmlIXsdElement* self, const gchar* value);
const gchar* gxml_ixsd_element_get_default (GXmlIXsdElement* self);
void gxml_ixsd_element_set_default (GXmlIXsdElement* self, const gchar* value);
const gchar* gxml_ixsd_element_get_final (GXmlIXsdElement* self);
void gxml_ixsd_element_set_final (GXmlIXsdElement* self, const gchar* value);
const gchar* gxml_ixsd_element_get_fixed (GXmlIXsdElement* self);
void gxml_ixsd_element_set_fixed (GXmlIXsdElement* self, const gchar* value);
const gchar* gxml_ixsd_element_get_form (GXmlIXsdElement* self);
void gxml_ixsd_element_set_form (GXmlIXsdElement* self, const gchar* value);
const gchar* gxml_ixsd_element_get_id (GXmlIXsdElement* self);
void gxml_ixsd_element_set_id (GXmlIXsdElement* self, const gchar* value);
const gchar* gxml_ixsd_element_get_maxOccurs (GXmlIXsdElement* self);
void gxml_ixsd_element_set_maxOccurs (GXmlIXsdElement* self, const gchar* value);
const gchar* gxml_ixsd_element_get_minOccurs (GXmlIXsdElement* self);
void gxml_ixsd_element_set_minOccurs (GXmlIXsdElement* self, const gchar* value);
const gchar* gxml_ixsd_element_get_name (GXmlIXsdElement* self);
void gxml_ixsd_element_set_name (GXmlIXsdElement* self, const gchar* value);
gboolean gxml_ixsd_element_get_nillable (GXmlIXsdElement* self);
void gxml_ixsd_element_set_nillable (GXmlIXsdElement* self, gboolean value);
const gchar* gxml_ixsd_element_get_ref (GXmlIXsdElement* self);
void gxml_ixsd_element_set_ref (GXmlIXsdElement* self, const gchar* value);
GXmlDomTokenList* gxml_ixsd_element_get_substitution_group (GXmlIXsdElement* self);
void gxml_ixsd_element_set_substitution_group (GXmlIXsdElement* self, GXmlDomTokenList* value);
const gchar* gxml_ixsd_element_get_target_namespace (GXmlIXsdElement* self);
void gxml_ixsd_element_set_target_namespace (GXmlIXsdElement* self, const gchar* value);
const gchar* gxml_ixsd_element_get_object_type (GXmlIXsdElement* self);
void gxml_ixsd_element_set_object_type (GXmlIXsdElement* self, const gchar* value);
GXmlIXsdAnnotation* gxml_ixsd_element_get_anotation (GXmlIXsdElement* self);
void gxml_ixsd_element_set_anotation (GXmlIXsdElement* self, GXmlIXsdAnnotation* value);
GXmlIXsdSimpleType* gxml_ixsd_element_get_simple_type (GXmlIXsdElement* self);
void gxml_ixsd_element_set_simple_type (GXmlIXsdElement* self, GXmlIXsdSimpleType* value);
GXmlIXsdComplexType* gxml_ixsd_element_get_complex_type (GXmlIXsdElement* self);
void gxml_ixsd_element_set_complex_type (GXmlIXsdElement* self, GXmlIXsdComplexType* value);
GXmlIXsdAnnotation* gxml_ixsd_base_content_get_anotation (GXmlIXsdBaseContent* self);
void gxml_ixsd_base_content_set_anotation (GXmlIXsdBaseContent* self, GXmlIXsdAnnotation* value);
GType gxml_ixsd_simple_content_get_type (void) G_GNUC_CONST;
#define GXML_IXSD_SIMPLE_CONTENT_SCHEMA_NODE_NAME "simpleContent"
GType gxml_ixsd_complex_content_get_type (void) G_GNUC_CONST;
#define GXML_IXSD_COMPLEX_CONTENT_SCHEMA_NODE_NAME "complexContent"
GType gxml_ixsd_open_content_get_type (void) G_GNUC_CONST;
GType gxml_ixsd_base_attribute_get_type (void) G_GNUC_CONST;
GXmlIXsdAnnotation* gxml_ixsd_base_attribute_get_anotation (GXmlIXsdBaseAttribute* self);
void gxml_ixsd_base_attribute_set_anotation (GXmlIXsdBaseAttribute* self, GXmlIXsdAnnotation* value);
GType gxml_ixsd_attribute_get_type (void) G_GNUC_CONST;
#define GXML_IXSD_ATTRIBUTE_SCHEMA_NODE_NAME "attribute"
GType gxml_ixsd_attribute_group_get_type (void) G_GNUC_CONST;
#define GXML_IXSD_ATTRIBUTE_GROUP_SCHEMA_NODE_NAME "attributeGroup"
GXmlDomElement* gxml_ixsd_list_get_item (GXmlIXsdList* self, gint index);
void gxml_ixsd_list_append (GXmlIXsdList* self, GXmlDomElement* element);
void gxml_ixsd_list_remove (GXmlIXsdList* self, gint index);
gint gxml_ixsd_list_index_of (GXmlIXsdList* self, GXmlDomElement* element);
GXmlDomElement* gxml_ixsd_list_get_element (GXmlIXsdList* self);
void gxml_ixsd_list_set_element (GXmlIXsdList* self, GXmlDomElement* value);
GType gxml_ixsd_list_get_items_type (GXmlIXsdList* self);
void gxml_ixsd_list_set_items_type (GXmlIXsdList* self, GType value);
GType gxml_ixsd_list_get_items_name (GXmlIXsdList* self);
void gxml_ixsd_list_set_items_name (GXmlIXsdList* self, GType value);
gint gxml_ixsd_list_get_length (GXmlIXsdList* self);


GXmlIXsdListElements* gxml_ixsd_schema_get_element_definitions (GXmlIXsdSchema* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_SCHEMA_GET_INTERFACE (self)->get_element_definitions (self);
}


void gxml_ixsd_schema_set_element_definitions (GXmlIXsdSchema* self, GXmlIXsdListElements* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_SCHEMA_GET_INTERFACE (self)->set_element_definitions (self, value);
}


GXmlIXsdListSimpleTypes* gxml_ixsd_schema_get_simple_type_definitions (GXmlIXsdSchema* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_SCHEMA_GET_INTERFACE (self)->get_simple_type_definitions (self);
}


void gxml_ixsd_schema_set_simple_type_definitions (GXmlIXsdSchema* self, GXmlIXsdListSimpleTypes* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_SCHEMA_GET_INTERFACE (self)->set_simple_type_definitions (self, value);
}


GXmlIXsdListComplexTypes* gxml_ixsd_schema_get_complex_type_definitions (GXmlIXsdSchema* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_SCHEMA_GET_INTERFACE (self)->get_complex_type_definitions (self);
}


void gxml_ixsd_schema_set_complex_type_definitions (GXmlIXsdSchema* self, GXmlIXsdListComplexTypes* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_SCHEMA_GET_INTERFACE (self)->set_complex_type_definitions (self, value);
}


static void gxml_ixsd_schema_base_init (GXmlIXsdSchemaIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
		g_object_interface_install_property (iface, g_param_spec_object ("element-definitions", "element-definitions", "element-definitions", GXML_TYPE_IXSD_LIST_ELEMENTS, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		g_object_interface_install_property (iface, g_param_spec_object ("simple-type-definitions", "simple-type-definitions", "simple-type-definitions", GXML_TYPE_IXSD_LIST_SIMPLE_TYPES, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		g_object_interface_install_property (iface, g_param_spec_object ("complex-type-definitions", "complex-type-definitions", "complex-type-definitions", GXML_TYPE_IXSD_LIST_COMPLEX_TYPES, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	}
}


/**
 * Reference interfaces for XSD support.
 */
GType gxml_ixsd_schema_get_type (void) {
	static volatile gsize gxml_ixsd_schema_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_schema_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdSchemaIface), (GBaseInitFunc) gxml_ixsd_schema_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_schema_type_id;
		gxml_ixsd_schema_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdSchema", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_schema_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (gxml_ixsd_schema_type_id, GXML_TYPE_DOM_ELEMENT);
		g_once_init_leave (&gxml_ixsd_schema_type_id__volatile, gxml_ixsd_schema_type_id);
	}
	return gxml_ixsd_schema_type_id__volatile;
}


GQuark gxml_ixsd_schema_error_quark (void) {
	return g_quark_from_static_string ("gxml_ixsd_schema_error-quark");
}


GXmlIXsdAnnotation* gxml_ixsd_base_type_get_anotation (GXmlIXsdBaseType* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_BASE_TYPE_GET_INTERFACE (self)->get_anotation (self);
}


void gxml_ixsd_base_type_set_anotation (GXmlIXsdBaseType* self, GXmlIXsdAnnotation* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_BASE_TYPE_GET_INTERFACE (self)->set_anotation (self, value);
}


static void gxml_ixsd_base_type_base_init (GXmlIXsdBaseTypeIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
		g_object_interface_install_property (iface, g_param_spec_object ("anotation", "anotation", "anotation", GXML_TYPE_IXSD_ANNOTATION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	}
}


GType gxml_ixsd_base_type_get_type (void) {
	static volatile gsize gxml_ixsd_base_type_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_base_type_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdBaseTypeIface), (GBaseInitFunc) gxml_ixsd_base_type_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_base_type_type_id;
		gxml_ixsd_base_type_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdBaseType", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_base_type_type_id, G_TYPE_OBJECT);
		g_once_init_leave (&gxml_ixsd_base_type_type_id__volatile, gxml_ixsd_base_type_type_id);
	}
	return gxml_ixsd_base_type_type_id__volatile;
}


const gchar* gxml_ixsd_simple_type_get_final (GXmlIXsdSimpleType* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_SIMPLE_TYPE_GET_INTERFACE (self)->get_final (self);
}


void gxml_ixsd_simple_type_set_final (GXmlIXsdSimpleType* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_SIMPLE_TYPE_GET_INTERFACE (self)->set_final (self, value);
}


const gchar* gxml_ixsd_simple_type_get_id (GXmlIXsdSimpleType* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_SIMPLE_TYPE_GET_INTERFACE (self)->get_id (self);
}


void gxml_ixsd_simple_type_set_id (GXmlIXsdSimpleType* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_SIMPLE_TYPE_GET_INTERFACE (self)->set_id (self, value);
}


const gchar* gxml_ixsd_simple_type_get_name (GXmlIXsdSimpleType* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_SIMPLE_TYPE_GET_INTERFACE (self)->get_name (self);
}


void gxml_ixsd_simple_type_set_name (GXmlIXsdSimpleType* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_SIMPLE_TYPE_GET_INTERFACE (self)->set_name (self, value);
}


GXmlIXsdAnnotation* gxml_ixsd_simple_type_get_annotation (GXmlIXsdSimpleType* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_SIMPLE_TYPE_GET_INTERFACE (self)->get_annotation (self);
}


void gxml_ixsd_simple_type_set_annotation (GXmlIXsdSimpleType* self, GXmlIXsdAnnotation* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_SIMPLE_TYPE_GET_INTERFACE (self)->set_annotation (self, value);
}


GXmlIXsdTypeList* gxml_ixsd_simple_type_get_list (GXmlIXsdSimpleType* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_SIMPLE_TYPE_GET_INTERFACE (self)->get_list (self);
}


void gxml_ixsd_simple_type_set_list (GXmlIXsdSimpleType* self, GXmlIXsdTypeList* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_SIMPLE_TYPE_GET_INTERFACE (self)->set_list (self, value);
}


GXmlIXsdTypeUnion* gxml_ixsd_simple_type_get_union (GXmlIXsdSimpleType* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_SIMPLE_TYPE_GET_INTERFACE (self)->get_union (self);
}


void gxml_ixsd_simple_type_set_union (GXmlIXsdSimpleType* self, GXmlIXsdTypeUnion* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_SIMPLE_TYPE_GET_INTERFACE (self)->set_union (self, value);
}


GXmlIXsdTypeRestriction* gxml_ixsd_simple_type_get_restriction (GXmlIXsdSimpleType* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_SIMPLE_TYPE_GET_INTERFACE (self)->get_restriction (self);
}


void gxml_ixsd_simple_type_set_restriction (GXmlIXsdSimpleType* self, GXmlIXsdTypeRestriction* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_SIMPLE_TYPE_GET_INTERFACE (self)->set_restriction (self, value);
}


static void gxml_ixsd_simple_type_base_init (GXmlIXsdSimpleTypeIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
		/**
		   * (#all | List of (list | union | restriction | extension))
		   */
		g_object_interface_install_property (iface, g_param_spec_string ("final", "final", "final", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		g_object_interface_install_property (iface, g_param_spec_string ("id", "id", "id", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		g_object_interface_install_property (iface, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		g_object_interface_install_property (iface, g_param_spec_object ("annotation", "annotation", "annotation", GXML_TYPE_IXSD_ANNOTATION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		g_object_interface_install_property (iface, g_param_spec_object ("list", "list", "list", GXML_TYPE_IXSD_TYPE_LIST, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		g_object_interface_install_property (iface, g_param_spec_object ("union", "union", "union", GXML_TYPE_IXSD_TYPE_UNION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		g_object_interface_install_property (iface, g_param_spec_object ("restriction", "restriction", "restriction", GXML_TYPE_IXSD_TYPE_RESTRICTION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	}
}


GType gxml_ixsd_simple_type_get_type (void) {
	static volatile gsize gxml_ixsd_simple_type_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_simple_type_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdSimpleTypeIface), (GBaseInitFunc) gxml_ixsd_simple_type_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_simple_type_type_id;
		gxml_ixsd_simple_type_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdSimpleType", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_simple_type_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (gxml_ixsd_simple_type_type_id, GXML_TYPE_DOM_ELEMENT);
		g_type_interface_add_prerequisite (gxml_ixsd_simple_type_type_id, GXML_TYPE_IXSD_BASE_TYPE);
		g_once_init_leave (&gxml_ixsd_simple_type_type_id__volatile, gxml_ixsd_simple_type_type_id);
	}
	return gxml_ixsd_simple_type_type_id__volatile;
}


static void gxml_ixsd_type_def_base_init (GXmlIXsdTypeDefIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
	}
}


GType gxml_ixsd_type_def_get_type (void) {
	static volatile gsize gxml_ixsd_type_def_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_type_def_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdTypeDefIface), (GBaseInitFunc) gxml_ixsd_type_def_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_type_def_type_id;
		gxml_ixsd_type_def_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdTypeDef", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_type_def_type_id, G_TYPE_OBJECT);
		g_once_init_leave (&gxml_ixsd_type_def_type_id__volatile, gxml_ixsd_type_def_type_id);
	}
	return gxml_ixsd_type_def_type_id__volatile;
}


const gchar* gxml_ixsd_type_restriction_get_base (GXmlIXsdTypeRestriction* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_TYPE_RESTRICTION_GET_INTERFACE (self)->get_base (self);
}


void gxml_ixsd_type_restriction_set_base (GXmlIXsdTypeRestriction* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_TYPE_RESTRICTION_GET_INTERFACE (self)->set_base (self, value);
}


const gchar* gxml_ixsd_type_restriction_get_id (GXmlIXsdTypeRestriction* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_TYPE_RESTRICTION_GET_INTERFACE (self)->get_id (self);
}


void gxml_ixsd_type_restriction_set_id (GXmlIXsdTypeRestriction* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_TYPE_RESTRICTION_GET_INTERFACE (self)->set_id (self, value);
}


GXmlIXsdSimpleType* gxml_ixsd_type_restriction_get_simple_type (GXmlIXsdTypeRestriction* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_TYPE_RESTRICTION_GET_INTERFACE (self)->get_simple_type (self);
}


void gxml_ixsd_type_restriction_set_simple_type (GXmlIXsdTypeRestriction* self, GXmlIXsdSimpleType* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_TYPE_RESTRICTION_GET_INTERFACE (self)->set_simple_type (self, value);
}


GXmlIXsdListTypeRestrictionEnumerations* gxml_ixsd_type_restriction_get_enumerations (GXmlIXsdTypeRestriction* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_TYPE_RESTRICTION_GET_INTERFACE (self)->get_enumerations (self);
}


void gxml_ixsd_type_restriction_set_enumerations (GXmlIXsdTypeRestriction* self, GXmlIXsdListTypeRestrictionEnumerations* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_TYPE_RESTRICTION_GET_INTERFACE (self)->set_enumerations (self, value);
}


GXmlIXsdListTypeRestrictionWhiteSpaces* gxml_ixsd_type_restriction_get_white_spaces (GXmlIXsdTypeRestriction* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_TYPE_RESTRICTION_GET_INTERFACE (self)->get_white_spaces (self);
}


void gxml_ixsd_type_restriction_set_white_spaces (GXmlIXsdTypeRestriction* self, GXmlIXsdListTypeRestrictionWhiteSpaces* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_TYPE_RESTRICTION_GET_INTERFACE (self)->set_white_spaces (self, value);
}


static void gxml_ixsd_type_restriction_base_init (GXmlIXsdTypeRestrictionIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
		g_object_interface_install_property (iface, g_param_spec_string ("base", "base", "base", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		g_object_interface_install_property (iface, g_param_spec_string ("id", "id", "id", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		g_object_interface_install_property (iface, g_param_spec_object ("simple-type", "simple-type", "simple-type", GXML_TYPE_IXSD_SIMPLE_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		g_object_interface_install_property (iface, g_param_spec_object ("enumerations", "enumerations", "enumerations", GXML_TYPE_IXSD_LIST_TYPE_RESTRICTION_ENUMERATIONS, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		g_object_interface_install_property (iface, g_param_spec_object ("white-spaces", "white-spaces", "white-spaces", GXML_TYPE_IXSD_LIST_TYPE_RESTRICTION_WHITE_SPACES, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	}
}


GType gxml_ixsd_type_restriction_get_type (void) {
	static volatile gsize gxml_ixsd_type_restriction_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_type_restriction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdTypeRestrictionIface), (GBaseInitFunc) gxml_ixsd_type_restriction_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_type_restriction_type_id;
		gxml_ixsd_type_restriction_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdTypeRestriction", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_type_restriction_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (gxml_ixsd_type_restriction_type_id, GXML_TYPE_IXSD_TYPE_DEF);
		g_once_init_leave (&gxml_ixsd_type_restriction_type_id__volatile, gxml_ixsd_type_restriction_type_id);
	}
	return gxml_ixsd_type_restriction_type_id__volatile;
}


static void gxml_ixsd_type_list_base_init (GXmlIXsdTypeListIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
	}
}


GType gxml_ixsd_type_list_get_type (void) {
	static volatile gsize gxml_ixsd_type_list_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_type_list_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdTypeListIface), (GBaseInitFunc) gxml_ixsd_type_list_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_type_list_type_id;
		gxml_ixsd_type_list_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdTypeList", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_type_list_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (gxml_ixsd_type_list_type_id, GXML_TYPE_IXSD_TYPE_DEF);
		g_once_init_leave (&gxml_ixsd_type_list_type_id__volatile, gxml_ixsd_type_list_type_id);
	}
	return gxml_ixsd_type_list_type_id__volatile;
}


static void gxml_ixsd_type_union_base_init (GXmlIXsdTypeUnionIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
	}
}


GType gxml_ixsd_type_union_get_type (void) {
	static volatile gsize gxml_ixsd_type_union_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_type_union_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdTypeUnionIface), (GBaseInitFunc) gxml_ixsd_type_union_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_type_union_type_id;
		gxml_ixsd_type_union_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdTypeUnion", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_type_union_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (gxml_ixsd_type_union_type_id, GXML_TYPE_IXSD_TYPE_DEF);
		g_once_init_leave (&gxml_ixsd_type_union_type_id__volatile, gxml_ixsd_type_union_type_id);
	}
	return gxml_ixsd_type_union_type_id__volatile;
}


GXmlIXsdAnnotation* gxml_ixsd_type_restriction_def_get_annotation (GXmlIXsdTypeRestrictionDef* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_TYPE_RESTRICTION_DEF_GET_INTERFACE (self)->get_annotation (self);
}


void gxml_ixsd_type_restriction_def_set_annotation (GXmlIXsdTypeRestrictionDef* self, GXmlIXsdAnnotation* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_TYPE_RESTRICTION_DEF_GET_INTERFACE (self)->set_annotation (self, value);
}


static void gxml_ixsd_type_restriction_def_base_init (GXmlIXsdTypeRestrictionDefIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
		g_object_interface_install_property (iface, g_param_spec_object ("annotation", "annotation", "annotation", GXML_TYPE_IXSD_ANNOTATION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	}
}


GType gxml_ixsd_type_restriction_def_get_type (void) {
	static volatile gsize gxml_ixsd_type_restriction_def_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_type_restriction_def_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdTypeRestrictionDefIface), (GBaseInitFunc) gxml_ixsd_type_restriction_def_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_type_restriction_def_type_id;
		gxml_ixsd_type_restriction_def_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdTypeRestrictionDef", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_type_restriction_def_type_id, G_TYPE_OBJECT);
		g_once_init_leave (&gxml_ixsd_type_restriction_def_type_id__volatile, gxml_ixsd_type_restriction_def_type_id);
	}
	return gxml_ixsd_type_restriction_def_type_id__volatile;
}


static void gxml_ixsd_type_restriction_min_exclusive_base_init (GXmlIXsdTypeRestrictionMinExclusiveIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
	}
}


GType gxml_ixsd_type_restriction_min_exclusive_get_type (void) {
	static volatile gsize gxml_ixsd_type_restriction_min_exclusive_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_type_restriction_min_exclusive_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdTypeRestrictionMinExclusiveIface), (GBaseInitFunc) gxml_ixsd_type_restriction_min_exclusive_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_type_restriction_min_exclusive_type_id;
		gxml_ixsd_type_restriction_min_exclusive_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdTypeRestrictionMinExclusive", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_type_restriction_min_exclusive_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (gxml_ixsd_type_restriction_min_exclusive_type_id, GXML_TYPE_IXSD_TYPE_RESTRICTION_DEF);
		g_once_init_leave (&gxml_ixsd_type_restriction_min_exclusive_type_id__volatile, gxml_ixsd_type_restriction_min_exclusive_type_id);
	}
	return gxml_ixsd_type_restriction_min_exclusive_type_id__volatile;
}


static void gxml_ixsd_type_restriction_min_inclusive_base_init (GXmlIXsdTypeRestrictionMinInclusiveIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
	}
}


GType gxml_ixsd_type_restriction_min_inclusive_get_type (void) {
	static volatile gsize gxml_ixsd_type_restriction_min_inclusive_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_type_restriction_min_inclusive_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdTypeRestrictionMinInclusiveIface), (GBaseInitFunc) gxml_ixsd_type_restriction_min_inclusive_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_type_restriction_min_inclusive_type_id;
		gxml_ixsd_type_restriction_min_inclusive_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdTypeRestrictionMinInclusive", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_type_restriction_min_inclusive_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (gxml_ixsd_type_restriction_min_inclusive_type_id, GXML_TYPE_IXSD_TYPE_RESTRICTION_DEF);
		g_once_init_leave (&gxml_ixsd_type_restriction_min_inclusive_type_id__volatile, gxml_ixsd_type_restriction_min_inclusive_type_id);
	}
	return gxml_ixsd_type_restriction_min_inclusive_type_id__volatile;
}


static void gxml_ixsd_type_restriction_max_exclusive_base_init (GXmlIXsdTypeRestrictionMaxExclusiveIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
	}
}


GType gxml_ixsd_type_restriction_max_exclusive_get_type (void) {
	static volatile gsize gxml_ixsd_type_restriction_max_exclusive_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_type_restriction_max_exclusive_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdTypeRestrictionMaxExclusiveIface), (GBaseInitFunc) gxml_ixsd_type_restriction_max_exclusive_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_type_restriction_max_exclusive_type_id;
		gxml_ixsd_type_restriction_max_exclusive_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdTypeRestrictionMaxExclusive", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_type_restriction_max_exclusive_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (gxml_ixsd_type_restriction_max_exclusive_type_id, GXML_TYPE_IXSD_TYPE_RESTRICTION_DEF);
		g_once_init_leave (&gxml_ixsd_type_restriction_max_exclusive_type_id__volatile, gxml_ixsd_type_restriction_max_exclusive_type_id);
	}
	return gxml_ixsd_type_restriction_max_exclusive_type_id__volatile;
}


static void gxml_ixsd_type_restriction_max_inclusive_base_init (GXmlIXsdTypeRestrictionMaxInclusiveIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
	}
}


GType gxml_ixsd_type_restriction_max_inclusive_get_type (void) {
	static volatile gsize gxml_ixsd_type_restriction_max_inclusive_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_type_restriction_max_inclusive_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdTypeRestrictionMaxInclusiveIface), (GBaseInitFunc) gxml_ixsd_type_restriction_max_inclusive_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_type_restriction_max_inclusive_type_id;
		gxml_ixsd_type_restriction_max_inclusive_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdTypeRestrictionMaxInclusive", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_type_restriction_max_inclusive_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (gxml_ixsd_type_restriction_max_inclusive_type_id, GXML_TYPE_IXSD_TYPE_RESTRICTION_DEF);
		g_once_init_leave (&gxml_ixsd_type_restriction_max_inclusive_type_id__volatile, gxml_ixsd_type_restriction_max_inclusive_type_id);
	}
	return gxml_ixsd_type_restriction_max_inclusive_type_id__volatile;
}


static void gxml_ixsd_type_restriction_total_digits_base_init (GXmlIXsdTypeRestrictionTotalDigitsIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
	}
}


GType gxml_ixsd_type_restriction_total_digits_get_type (void) {
	static volatile gsize gxml_ixsd_type_restriction_total_digits_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_type_restriction_total_digits_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdTypeRestrictionTotalDigitsIface), (GBaseInitFunc) gxml_ixsd_type_restriction_total_digits_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_type_restriction_total_digits_type_id;
		gxml_ixsd_type_restriction_total_digits_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdTypeRestrictionTotalDigits", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_type_restriction_total_digits_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (gxml_ixsd_type_restriction_total_digits_type_id, GXML_TYPE_IXSD_TYPE_RESTRICTION_DEF);
		g_once_init_leave (&gxml_ixsd_type_restriction_total_digits_type_id__volatile, gxml_ixsd_type_restriction_total_digits_type_id);
	}
	return gxml_ixsd_type_restriction_total_digits_type_id__volatile;
}


static void gxml_ixsd_type_restriction_fraction_digits_base_init (GXmlIXsdTypeRestrictionFractionDigitsIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
	}
}


GType gxml_ixsd_type_restriction_fraction_digits_get_type (void) {
	static volatile gsize gxml_ixsd_type_restriction_fraction_digits_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_type_restriction_fraction_digits_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdTypeRestrictionFractionDigitsIface), (GBaseInitFunc) gxml_ixsd_type_restriction_fraction_digits_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_type_restriction_fraction_digits_type_id;
		gxml_ixsd_type_restriction_fraction_digits_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdTypeRestrictionFractionDigits", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_type_restriction_fraction_digits_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (gxml_ixsd_type_restriction_fraction_digits_type_id, GXML_TYPE_IXSD_TYPE_RESTRICTION_DEF);
		g_once_init_leave (&gxml_ixsd_type_restriction_fraction_digits_type_id__volatile, gxml_ixsd_type_restriction_fraction_digits_type_id);
	}
	return gxml_ixsd_type_restriction_fraction_digits_type_id__volatile;
}


static void gxml_ixsd_type_restriction_length_base_init (GXmlIXsdTypeRestrictionLengthIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
	}
}


GType gxml_ixsd_type_restriction_length_get_type (void) {
	static volatile gsize gxml_ixsd_type_restriction_length_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_type_restriction_length_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdTypeRestrictionLengthIface), (GBaseInitFunc) gxml_ixsd_type_restriction_length_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_type_restriction_length_type_id;
		gxml_ixsd_type_restriction_length_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdTypeRestrictionLength", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_type_restriction_length_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (gxml_ixsd_type_restriction_length_type_id, GXML_TYPE_IXSD_TYPE_RESTRICTION_DEF);
		g_once_init_leave (&gxml_ixsd_type_restriction_length_type_id__volatile, gxml_ixsd_type_restriction_length_type_id);
	}
	return gxml_ixsd_type_restriction_length_type_id__volatile;
}


static void gxml_ixsd_type_restriction_min_length_base_init (GXmlIXsdTypeRestrictionMinLengthIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
	}
}


GType gxml_ixsd_type_restriction_min_length_get_type (void) {
	static volatile gsize gxml_ixsd_type_restriction_min_length_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_type_restriction_min_length_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdTypeRestrictionMinLengthIface), (GBaseInitFunc) gxml_ixsd_type_restriction_min_length_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_type_restriction_min_length_type_id;
		gxml_ixsd_type_restriction_min_length_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdTypeRestrictionMinLength", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_type_restriction_min_length_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (gxml_ixsd_type_restriction_min_length_type_id, GXML_TYPE_IXSD_TYPE_RESTRICTION_DEF);
		g_once_init_leave (&gxml_ixsd_type_restriction_min_length_type_id__volatile, gxml_ixsd_type_restriction_min_length_type_id);
	}
	return gxml_ixsd_type_restriction_min_length_type_id__volatile;
}


static void gxml_ixsd_type_restriction_max_length_base_init (GXmlIXsdTypeRestrictionMaxLengthIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
	}
}


GType gxml_ixsd_type_restriction_max_length_get_type (void) {
	static volatile gsize gxml_ixsd_type_restriction_max_length_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_type_restriction_max_length_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdTypeRestrictionMaxLengthIface), (GBaseInitFunc) gxml_ixsd_type_restriction_max_length_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_type_restriction_max_length_type_id;
		gxml_ixsd_type_restriction_max_length_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdTypeRestrictionMaxLength", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_type_restriction_max_length_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (gxml_ixsd_type_restriction_max_length_type_id, GXML_TYPE_IXSD_TYPE_RESTRICTION_DEF);
		g_once_init_leave (&gxml_ixsd_type_restriction_max_length_type_id__volatile, gxml_ixsd_type_restriction_max_length_type_id);
	}
	return gxml_ixsd_type_restriction_max_length_type_id__volatile;
}


const gchar* gxml_ixsd_type_restriction_enumeration_get_id (GXmlIXsdTypeRestrictionEnumeration* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_TYPE_RESTRICTION_ENUMERATION_GET_INTERFACE (self)->get_id (self);
}


void gxml_ixsd_type_restriction_enumeration_set_id (GXmlIXsdTypeRestrictionEnumeration* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_TYPE_RESTRICTION_ENUMERATION_GET_INTERFACE (self)->set_id (self, value);
}


const gchar* gxml_ixsd_type_restriction_enumeration_get_value (GXmlIXsdTypeRestrictionEnumeration* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_TYPE_RESTRICTION_ENUMERATION_GET_INTERFACE (self)->get_value (self);
}


void gxml_ixsd_type_restriction_enumeration_set_value (GXmlIXsdTypeRestrictionEnumeration* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_TYPE_RESTRICTION_ENUMERATION_GET_INTERFACE (self)->set_value (self, value);
}


static void gxml_ixsd_type_restriction_enumeration_base_init (GXmlIXsdTypeRestrictionEnumerationIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
		g_object_interface_install_property (iface, g_param_spec_string ("id", "id", "id", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		g_object_interface_install_property (iface, g_param_spec_string ("value", "value", "value", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	}
}


GType gxml_ixsd_type_restriction_enumeration_get_type (void) {
	static volatile gsize gxml_ixsd_type_restriction_enumeration_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_type_restriction_enumeration_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdTypeRestrictionEnumerationIface), (GBaseInitFunc) gxml_ixsd_type_restriction_enumeration_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_type_restriction_enumeration_type_id;
		gxml_ixsd_type_restriction_enumeration_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdTypeRestrictionEnumeration", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_type_restriction_enumeration_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (gxml_ixsd_type_restriction_enumeration_type_id, GXML_TYPE_IXSD_TYPE_RESTRICTION_DEF);
		g_once_init_leave (&gxml_ixsd_type_restriction_enumeration_type_id__volatile, gxml_ixsd_type_restriction_enumeration_type_id);
	}
	return gxml_ixsd_type_restriction_enumeration_type_id__volatile;
}


gboolean gxml_ixsd_type_restriction_white_space_get_fixed (GXmlIXsdTypeRestrictionWhiteSpace* self) {
	g_return_val_if_fail (self != NULL, FALSE);
	return GXML_IXSD_TYPE_RESTRICTION_WHITE_SPACE_GET_INTERFACE (self)->get_fixed (self);
}


void gxml_ixsd_type_restriction_white_space_set_fixed (GXmlIXsdTypeRestrictionWhiteSpace* self, gboolean value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_TYPE_RESTRICTION_WHITE_SPACE_GET_INTERFACE (self)->set_fixed (self, value);
}


const gchar* gxml_ixsd_type_restriction_white_space_get_id (GXmlIXsdTypeRestrictionWhiteSpace* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_TYPE_RESTRICTION_WHITE_SPACE_GET_INTERFACE (self)->get_id (self);
}


void gxml_ixsd_type_restriction_white_space_set_id (GXmlIXsdTypeRestrictionWhiteSpace* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_TYPE_RESTRICTION_WHITE_SPACE_GET_INTERFACE (self)->set_id (self, value);
}


const gchar* gxml_ixsd_type_restriction_white_space_get_value (GXmlIXsdTypeRestrictionWhiteSpace* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_TYPE_RESTRICTION_WHITE_SPACE_GET_INTERFACE (self)->get_value (self);
}


void gxml_ixsd_type_restriction_white_space_set_value (GXmlIXsdTypeRestrictionWhiteSpace* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_TYPE_RESTRICTION_WHITE_SPACE_GET_INTERFACE (self)->set_value (self, value);
}


static void gxml_ixsd_type_restriction_white_space_base_init (GXmlIXsdTypeRestrictionWhiteSpaceIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
		g_object_interface_install_property (iface, g_param_spec_boolean ("fixed", "fixed", "fixed", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		g_object_interface_install_property (iface, g_param_spec_string ("id", "id", "id", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		/**
		   * (collapse | preserve | replace)
		   */
		g_object_interface_install_property (iface, g_param_spec_string ("value", "value", "value", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	}
}


GType gxml_ixsd_type_restriction_white_space_get_type (void) {
	static volatile gsize gxml_ixsd_type_restriction_white_space_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_type_restriction_white_space_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdTypeRestrictionWhiteSpaceIface), (GBaseInitFunc) gxml_ixsd_type_restriction_white_space_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_type_restriction_white_space_type_id;
		gxml_ixsd_type_restriction_white_space_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdTypeRestrictionWhiteSpace", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_type_restriction_white_space_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (gxml_ixsd_type_restriction_white_space_type_id, GXML_TYPE_IXSD_TYPE_RESTRICTION_DEF);
		g_once_init_leave (&gxml_ixsd_type_restriction_white_space_type_id__volatile, gxml_ixsd_type_restriction_white_space_type_id);
	}
	return gxml_ixsd_type_restriction_white_space_type_id__volatile;
}


static void gxml_ixsd_type_restriction_pattern_base_init (GXmlIXsdTypeRestrictionPatternIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
	}
}


GType gxml_ixsd_type_restriction_pattern_get_type (void) {
	static volatile gsize gxml_ixsd_type_restriction_pattern_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_type_restriction_pattern_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdTypeRestrictionPatternIface), (GBaseInitFunc) gxml_ixsd_type_restriction_pattern_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_type_restriction_pattern_type_id;
		gxml_ixsd_type_restriction_pattern_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdTypeRestrictionPattern", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_type_restriction_pattern_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (gxml_ixsd_type_restriction_pattern_type_id, GXML_TYPE_IXSD_TYPE_RESTRICTION_DEF);
		g_once_init_leave (&gxml_ixsd_type_restriction_pattern_type_id__volatile, gxml_ixsd_type_restriction_pattern_type_id);
	}
	return gxml_ixsd_type_restriction_pattern_type_id__volatile;
}


static void gxml_ixsd_type_restriction_assertion_base_init (GXmlIXsdTypeRestrictionAssertionIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
	}
}


GType gxml_ixsd_type_restriction_assertion_get_type (void) {
	static volatile gsize gxml_ixsd_type_restriction_assertion_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_type_restriction_assertion_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdTypeRestrictionAssertionIface), (GBaseInitFunc) gxml_ixsd_type_restriction_assertion_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_type_restriction_assertion_type_id;
		gxml_ixsd_type_restriction_assertion_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdTypeRestrictionAssertion", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_type_restriction_assertion_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (gxml_ixsd_type_restriction_assertion_type_id, GXML_TYPE_IXSD_TYPE_RESTRICTION_DEF);
		g_once_init_leave (&gxml_ixsd_type_restriction_assertion_type_id__volatile, gxml_ixsd_type_restriction_assertion_type_id);
	}
	return gxml_ixsd_type_restriction_assertion_type_id__volatile;
}


static void gxml_ixsd_type_restriction_explicit_timezone_base_init (GXmlIXsdTypeRestrictionExplicitTimezoneIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
	}
}


GType gxml_ixsd_type_restriction_explicit_timezone_get_type (void) {
	static volatile gsize gxml_ixsd_type_restriction_explicit_timezone_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_type_restriction_explicit_timezone_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdTypeRestrictionExplicitTimezoneIface), (GBaseInitFunc) gxml_ixsd_type_restriction_explicit_timezone_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_type_restriction_explicit_timezone_type_id;
		gxml_ixsd_type_restriction_explicit_timezone_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdTypeRestrictionExplicitTimezone", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_type_restriction_explicit_timezone_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (gxml_ixsd_type_restriction_explicit_timezone_type_id, GXML_TYPE_IXSD_TYPE_RESTRICTION_DEF);
		g_once_init_leave (&gxml_ixsd_type_restriction_explicit_timezone_type_id__volatile, gxml_ixsd_type_restriction_explicit_timezone_type_id);
	}
	return gxml_ixsd_type_restriction_explicit_timezone_type_id__volatile;
}


gboolean gxml_ixsd_complex_type_get_abstract (GXmlIXsdComplexType* self) {
	g_return_val_if_fail (self != NULL, FALSE);
	return GXML_IXSD_COMPLEX_TYPE_GET_INTERFACE (self)->get_abstract (self);
}


void gxml_ixsd_complex_type_set_abstract (GXmlIXsdComplexType* self, gboolean value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_COMPLEX_TYPE_GET_INTERFACE (self)->set_abstract (self, value);
}


const gchar* gxml_ixsd_complex_type_get_block (GXmlIXsdComplexType* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_COMPLEX_TYPE_GET_INTERFACE (self)->get_block (self);
}


void gxml_ixsd_complex_type_set_block (GXmlIXsdComplexType* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_COMPLEX_TYPE_GET_INTERFACE (self)->set_block (self, value);
}


const gchar* gxml_ixsd_complex_type_get_final (GXmlIXsdComplexType* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_COMPLEX_TYPE_GET_INTERFACE (self)->get_final (self);
}


void gxml_ixsd_complex_type_set_final (GXmlIXsdComplexType* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_COMPLEX_TYPE_GET_INTERFACE (self)->set_final (self, value);
}


gboolean gxml_ixsd_complex_type_get_mixed (GXmlIXsdComplexType* self) {
	g_return_val_if_fail (self != NULL, FALSE);
	return GXML_IXSD_COMPLEX_TYPE_GET_INTERFACE (self)->get_mixed (self);
}


void gxml_ixsd_complex_type_set_mixed (GXmlIXsdComplexType* self, gboolean value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_COMPLEX_TYPE_GET_INTERFACE (self)->set_mixed (self, value);
}


const gchar* gxml_ixsd_complex_type_get_name (GXmlIXsdComplexType* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_COMPLEX_TYPE_GET_INTERFACE (self)->get_name (self);
}


void gxml_ixsd_complex_type_set_name (GXmlIXsdComplexType* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_COMPLEX_TYPE_GET_INTERFACE (self)->set_name (self, value);
}


gboolean gxml_ixsd_complex_type_get_default_attributes_apply (GXmlIXsdComplexType* self) {
	g_return_val_if_fail (self != NULL, FALSE);
	return GXML_IXSD_COMPLEX_TYPE_GET_INTERFACE (self)->get_default_attributes_apply (self);
}


void gxml_ixsd_complex_type_set_default_attributes_apply (GXmlIXsdComplexType* self, gboolean value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_COMPLEX_TYPE_GET_INTERFACE (self)->set_default_attributes_apply (self, value);
}


GXmlIXsdBaseContent* gxml_ixsd_complex_type_get_content_type (GXmlIXsdComplexType* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_COMPLEX_TYPE_GET_INTERFACE (self)->get_content_type (self);
}


void gxml_ixsd_complex_type_set_content_type (GXmlIXsdComplexType* self, GXmlIXsdBaseContent* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_COMPLEX_TYPE_GET_INTERFACE (self)->set_content_type (self, value);
}


GXmlIXsdListAttributes* gxml_ixsd_complex_type_get_type_attributes (GXmlIXsdComplexType* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_COMPLEX_TYPE_GET_INTERFACE (self)->get_type_attributes (self);
}


GXmlIXsdListAttributesGroup* gxml_ixsd_complex_type_get_group_attributes (GXmlIXsdComplexType* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_COMPLEX_TYPE_GET_INTERFACE (self)->get_group_attributes (self);
}


static void gxml_ixsd_complex_type_base_init (GXmlIXsdComplexTypeIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
		/**
		  * attribute name = abstract
		  */
		g_object_interface_install_property (iface, g_param_spec_boolean ("abstract", "abstract", "abstract", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		/**
		  * (#all | List of (extension | restriction))
		  */
		g_object_interface_install_property (iface, g_param_spec_string ("block", "block", "block", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		/**
		  * (#all | List of (extension | restriction))
		  */
		g_object_interface_install_property (iface, g_param_spec_string ("final", "final", "final", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		g_object_interface_install_property (iface, g_param_spec_boolean ("mixed", "mixed", "mixed", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		g_object_interface_install_property (iface, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		/**
		   * defaultAttributesApply
		   */
		g_object_interface_install_property (iface, g_param_spec_boolean ("default-attributes-apply", "default-attributes-apply", "default-attributes-apply", TRUE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		/**
		   * A {@link IXsdComplexType} or {@link IXsdSimpleType}
		   */
		g_object_interface_install_property (iface, g_param_spec_object ("content-type", "content-type", "content-type", GXML_TYPE_IXSD_BASE_CONTENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		/**
		   * List of {@link IXsdAttribute} definitions
		   */
		g_object_interface_install_property (iface, g_param_spec_object ("type-attributes", "type-attributes", "type-attributes", GXML_TYPE_IXSD_LIST_ATTRIBUTES, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
		/**
		   * List of {@link IXsdAttributeGroup} definitions
		   */
		g_object_interface_install_property (iface, g_param_spec_object ("group-attributes", "group-attributes", "group-attributes", GXML_TYPE_IXSD_LIST_ATTRIBUTES_GROUP, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	}
}


GType gxml_ixsd_complex_type_get_type (void) {
	static volatile gsize gxml_ixsd_complex_type_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_complex_type_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdComplexTypeIface), (GBaseInitFunc) gxml_ixsd_complex_type_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_complex_type_type_id;
		gxml_ixsd_complex_type_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdComplexType", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_complex_type_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (gxml_ixsd_complex_type_type_id, GXML_TYPE_DOM_ELEMENT);
		g_type_interface_add_prerequisite (gxml_ixsd_complex_type_type_id, GXML_TYPE_IXSD_BASE_TYPE);
		g_once_init_leave (&gxml_ixsd_complex_type_type_id__volatile, gxml_ixsd_complex_type_type_id);
	}
	return gxml_ixsd_complex_type_type_id__volatile;
}


const gchar* gxml_ixsd_extension_get_base (GXmlIXsdExtension* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_EXTENSION_GET_INTERFACE (self)->get_base (self);
}


void gxml_ixsd_extension_set_base (GXmlIXsdExtension* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_EXTENSION_GET_INTERFACE (self)->set_base (self, value);
}


static void gxml_ixsd_extension_base_init (GXmlIXsdExtensionIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
		g_object_interface_install_property (iface, g_param_spec_string ("base", "base", "base", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	}
}


GType gxml_ixsd_extension_get_type (void) {
	static volatile gsize gxml_ixsd_extension_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_extension_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdExtensionIface), (GBaseInitFunc) gxml_ixsd_extension_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_extension_type_id;
		gxml_ixsd_extension_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdExtension", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_extension_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (gxml_ixsd_extension_type_id, GXML_TYPE_DOM_ELEMENT);
		g_once_init_leave (&gxml_ixsd_extension_type_id__volatile, gxml_ixsd_extension_type_id);
	}
	return gxml_ixsd_extension_type_id__volatile;
}


gboolean gxml_ixsd_element_get_abstract (GXmlIXsdElement* self) {
	g_return_val_if_fail (self != NULL, FALSE);
	return GXML_IXSD_ELEMENT_GET_INTERFACE (self)->get_abstract (self);
}


void gxml_ixsd_element_set_abstract (GXmlIXsdElement* self, gboolean value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_ELEMENT_GET_INTERFACE (self)->set_abstract (self, value);
}


const gchar* gxml_ixsd_element_get_block (GXmlIXsdElement* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_ELEMENT_GET_INTERFACE (self)->get_block (self);
}


void gxml_ixsd_element_set_block (GXmlIXsdElement* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_ELEMENT_GET_INTERFACE (self)->set_block (self, value);
}


const gchar* gxml_ixsd_element_get_default (GXmlIXsdElement* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_ELEMENT_GET_INTERFACE (self)->get_default (self);
}


void gxml_ixsd_element_set_default (GXmlIXsdElement* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_ELEMENT_GET_INTERFACE (self)->set_default (self, value);
}


const gchar* gxml_ixsd_element_get_final (GXmlIXsdElement* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_ELEMENT_GET_INTERFACE (self)->get_final (self);
}


void gxml_ixsd_element_set_final (GXmlIXsdElement* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_ELEMENT_GET_INTERFACE (self)->set_final (self, value);
}


const gchar* gxml_ixsd_element_get_fixed (GXmlIXsdElement* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_ELEMENT_GET_INTERFACE (self)->get_fixed (self);
}


void gxml_ixsd_element_set_fixed (GXmlIXsdElement* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_ELEMENT_GET_INTERFACE (self)->set_fixed (self, value);
}


const gchar* gxml_ixsd_element_get_form (GXmlIXsdElement* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_ELEMENT_GET_INTERFACE (self)->get_form (self);
}


void gxml_ixsd_element_set_form (GXmlIXsdElement* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_ELEMENT_GET_INTERFACE (self)->set_form (self, value);
}


const gchar* gxml_ixsd_element_get_id (GXmlIXsdElement* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_ELEMENT_GET_INTERFACE (self)->get_id (self);
}


void gxml_ixsd_element_set_id (GXmlIXsdElement* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_ELEMENT_GET_INTERFACE (self)->set_id (self, value);
}


const gchar* gxml_ixsd_element_get_maxOccurs (GXmlIXsdElement* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_ELEMENT_GET_INTERFACE (self)->get_maxOccurs (self);
}


void gxml_ixsd_element_set_maxOccurs (GXmlIXsdElement* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_ELEMENT_GET_INTERFACE (self)->set_maxOccurs (self, value);
}


const gchar* gxml_ixsd_element_get_minOccurs (GXmlIXsdElement* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_ELEMENT_GET_INTERFACE (self)->get_minOccurs (self);
}


void gxml_ixsd_element_set_minOccurs (GXmlIXsdElement* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_ELEMENT_GET_INTERFACE (self)->set_minOccurs (self, value);
}


const gchar* gxml_ixsd_element_get_name (GXmlIXsdElement* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_ELEMENT_GET_INTERFACE (self)->get_name (self);
}


void gxml_ixsd_element_set_name (GXmlIXsdElement* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_ELEMENT_GET_INTERFACE (self)->set_name (self, value);
}


gboolean gxml_ixsd_element_get_nillable (GXmlIXsdElement* self) {
	g_return_val_if_fail (self != NULL, FALSE);
	return GXML_IXSD_ELEMENT_GET_INTERFACE (self)->get_nillable (self);
}


void gxml_ixsd_element_set_nillable (GXmlIXsdElement* self, gboolean value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_ELEMENT_GET_INTERFACE (self)->set_nillable (self, value);
}


const gchar* gxml_ixsd_element_get_ref (GXmlIXsdElement* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_ELEMENT_GET_INTERFACE (self)->get_ref (self);
}


void gxml_ixsd_element_set_ref (GXmlIXsdElement* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_ELEMENT_GET_INTERFACE (self)->set_ref (self, value);
}


GXmlDomTokenList* gxml_ixsd_element_get_substitution_group (GXmlIXsdElement* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_ELEMENT_GET_INTERFACE (self)->get_substitution_group (self);
}


void gxml_ixsd_element_set_substitution_group (GXmlIXsdElement* self, GXmlDomTokenList* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_ELEMENT_GET_INTERFACE (self)->set_substitution_group (self, value);
}


const gchar* gxml_ixsd_element_get_target_namespace (GXmlIXsdElement* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_ELEMENT_GET_INTERFACE (self)->get_target_namespace (self);
}


void gxml_ixsd_element_set_target_namespace (GXmlIXsdElement* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_ELEMENT_GET_INTERFACE (self)->set_target_namespace (self, value);
}


const gchar* gxml_ixsd_element_get_object_type (GXmlIXsdElement* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_ELEMENT_GET_INTERFACE (self)->get_object_type (self);
}


void gxml_ixsd_element_set_object_type (GXmlIXsdElement* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_ELEMENT_GET_INTERFACE (self)->set_object_type (self, value);
}


GXmlIXsdAnnotation* gxml_ixsd_element_get_anotation (GXmlIXsdElement* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_ELEMENT_GET_INTERFACE (self)->get_anotation (self);
}


void gxml_ixsd_element_set_anotation (GXmlIXsdElement* self, GXmlIXsdAnnotation* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_ELEMENT_GET_INTERFACE (self)->set_anotation (self, value);
}


GXmlIXsdSimpleType* gxml_ixsd_element_get_simple_type (GXmlIXsdElement* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_ELEMENT_GET_INTERFACE (self)->get_simple_type (self);
}


void gxml_ixsd_element_set_simple_type (GXmlIXsdElement* self, GXmlIXsdSimpleType* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_ELEMENT_GET_INTERFACE (self)->set_simple_type (self, value);
}


GXmlIXsdComplexType* gxml_ixsd_element_get_complex_type (GXmlIXsdElement* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_ELEMENT_GET_INTERFACE (self)->get_complex_type (self);
}


void gxml_ixsd_element_set_complex_type (GXmlIXsdElement* self, GXmlIXsdComplexType* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_ELEMENT_GET_INTERFACE (self)->set_complex_type (self, value);
}


static void gxml_ixsd_element_base_init (GXmlIXsdElementIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
		/**
		  * attribute name = abstract
		  */
		g_object_interface_install_property (iface, g_param_spec_boolean ("abstract", "abstract", "abstract", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		/**
		   * (#all | List of (extension | restriction | substitution))
		  */
		g_object_interface_install_property (iface, g_param_spec_string ("block", "block", "block", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		g_object_interface_install_property (iface, g_param_spec_string ("default", "default", "default", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		/**
		   * (#all | List of (extension | restriction))
		   */
		g_object_interface_install_property (iface, g_param_spec_string ("final", "final", "final", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		g_object_interface_install_property (iface, g_param_spec_string ("fixed", "fixed", "fixed", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		/**
		   * (qualified | unqualified)
		   */
		g_object_interface_install_property (iface, g_param_spec_string ("form", "form", "form", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		g_object_interface_install_property (iface, g_param_spec_string ("id", "id", "id", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		/**
		   * (nonNegativeInteger | unbounded)  : 1
		   */
		g_object_interface_install_property (iface, g_param_spec_string ("maxOccurs", "maxOccurs", "maxOccurs", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		/**
		   * nonNegativeInteger : 1
		   */
		g_object_interface_install_property (iface, g_param_spec_string ("minOccurs", "minOccurs", "minOccurs", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		g_object_interface_install_property (iface, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		g_object_interface_install_property (iface, g_param_spec_boolean ("nillable", "nillable", "nillable", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		g_object_interface_install_property (iface, g_param_spec_string ("ref", "ref", "ref", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		/**
		   * substitutionGroup
		   */
		g_object_interface_install_property (iface, g_param_spec_object ("substitution-group", "substitution-group", "substitution-group", GXML_TYPE_DOM_TOKEN_LIST, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		/**
		   * targetNamespace
		   */
		g_object_interface_install_property (iface, g_param_spec_string ("target-namespace", "target-namespace", "target-namespace", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		/**
		   * attribute name = 'type'
		   */
		g_object_interface_install_property (iface, g_param_spec_string ("object-type", "object-type", "object-type", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		g_object_interface_install_property (iface, g_param_spec_object ("anotation", "anotation", "anotation", GXML_TYPE_IXSD_ANNOTATION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		g_object_interface_install_property (iface, g_param_spec_object ("simple-type", "simple-type", "simple-type", GXML_TYPE_IXSD_SIMPLE_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		g_object_interface_install_property (iface, g_param_spec_object ("complex-type", "complex-type", "complex-type", GXML_TYPE_IXSD_COMPLEX_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	}
}


GType gxml_ixsd_element_get_type (void) {
	static volatile gsize gxml_ixsd_element_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_element_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdElementIface), (GBaseInitFunc) gxml_ixsd_element_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_element_type_id;
		gxml_ixsd_element_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdElement", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_element_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (gxml_ixsd_element_type_id, GXML_TYPE_DOM_ELEMENT);
		g_once_init_leave (&gxml_ixsd_element_type_id__volatile, gxml_ixsd_element_type_id);
	}
	return gxml_ixsd_element_type_id__volatile;
}


static void gxml_ixsd_annotation_base_init (GXmlIXsdAnnotationIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
	}
}


GType gxml_ixsd_annotation_get_type (void) {
	static volatile gsize gxml_ixsd_annotation_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_annotation_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdAnnotationIface), (GBaseInitFunc) gxml_ixsd_annotation_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_annotation_type_id;
		gxml_ixsd_annotation_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdAnnotation", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_annotation_type_id, G_TYPE_OBJECT);
		g_once_init_leave (&gxml_ixsd_annotation_type_id__volatile, gxml_ixsd_annotation_type_id);
	}
	return gxml_ixsd_annotation_type_id__volatile;
}


GXmlIXsdAnnotation* gxml_ixsd_base_content_get_anotation (GXmlIXsdBaseContent* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_BASE_CONTENT_GET_INTERFACE (self)->get_anotation (self);
}


void gxml_ixsd_base_content_set_anotation (GXmlIXsdBaseContent* self, GXmlIXsdAnnotation* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_BASE_CONTENT_GET_INTERFACE (self)->set_anotation (self, value);
}


static void gxml_ixsd_base_content_base_init (GXmlIXsdBaseContentIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
		g_object_interface_install_property (iface, g_param_spec_object ("anotation", "anotation", "anotation", GXML_TYPE_IXSD_ANNOTATION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	}
}


GType gxml_ixsd_base_content_get_type (void) {
	static volatile gsize gxml_ixsd_base_content_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_base_content_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdBaseContentIface), (GBaseInitFunc) gxml_ixsd_base_content_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_base_content_type_id;
		gxml_ixsd_base_content_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdBaseContent", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_base_content_type_id, G_TYPE_OBJECT);
		g_once_init_leave (&gxml_ixsd_base_content_type_id__volatile, gxml_ixsd_base_content_type_id);
	}
	return gxml_ixsd_base_content_type_id__volatile;
}


static void gxml_ixsd_simple_content_base_init (GXmlIXsdSimpleContentIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
	}
}


GType gxml_ixsd_simple_content_get_type (void) {
	static volatile gsize gxml_ixsd_simple_content_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_simple_content_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdSimpleContentIface), (GBaseInitFunc) gxml_ixsd_simple_content_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_simple_content_type_id;
		gxml_ixsd_simple_content_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdSimpleContent", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_simple_content_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (gxml_ixsd_simple_content_type_id, GXML_TYPE_IXSD_BASE_CONTENT);
		g_once_init_leave (&gxml_ixsd_simple_content_type_id__volatile, gxml_ixsd_simple_content_type_id);
	}
	return gxml_ixsd_simple_content_type_id__volatile;
}


static void gxml_ixsd_complex_content_base_init (GXmlIXsdComplexContentIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
	}
}


GType gxml_ixsd_complex_content_get_type (void) {
	static volatile gsize gxml_ixsd_complex_content_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_complex_content_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdComplexContentIface), (GBaseInitFunc) gxml_ixsd_complex_content_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_complex_content_type_id;
		gxml_ixsd_complex_content_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdComplexContent", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_complex_content_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (gxml_ixsd_complex_content_type_id, GXML_TYPE_IXSD_BASE_CONTENT);
		g_once_init_leave (&gxml_ixsd_complex_content_type_id__volatile, gxml_ixsd_complex_content_type_id);
	}
	return gxml_ixsd_complex_content_type_id__volatile;
}


static void gxml_ixsd_open_content_base_init (GXmlIXsdOpenContentIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
	}
}


GType gxml_ixsd_open_content_get_type (void) {
	static volatile gsize gxml_ixsd_open_content_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_open_content_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdOpenContentIface), (GBaseInitFunc) gxml_ixsd_open_content_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_open_content_type_id;
		gxml_ixsd_open_content_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdOpenContent", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_open_content_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (gxml_ixsd_open_content_type_id, GXML_TYPE_IXSD_BASE_CONTENT);
		g_once_init_leave (&gxml_ixsd_open_content_type_id__volatile, gxml_ixsd_open_content_type_id);
	}
	return gxml_ixsd_open_content_type_id__volatile;
}


GXmlIXsdAnnotation* gxml_ixsd_base_attribute_get_anotation (GXmlIXsdBaseAttribute* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_BASE_ATTRIBUTE_GET_INTERFACE (self)->get_anotation (self);
}


void gxml_ixsd_base_attribute_set_anotation (GXmlIXsdBaseAttribute* self, GXmlIXsdAnnotation* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_BASE_ATTRIBUTE_GET_INTERFACE (self)->set_anotation (self, value);
}


static void gxml_ixsd_base_attribute_base_init (GXmlIXsdBaseAttributeIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
		g_object_interface_install_property (iface, g_param_spec_object ("anotation", "anotation", "anotation", GXML_TYPE_IXSD_ANNOTATION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	}
}


GType gxml_ixsd_base_attribute_get_type (void) {
	static volatile gsize gxml_ixsd_base_attribute_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_base_attribute_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdBaseAttributeIface), (GBaseInitFunc) gxml_ixsd_base_attribute_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_base_attribute_type_id;
		gxml_ixsd_base_attribute_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdBaseAttribute", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_base_attribute_type_id, G_TYPE_OBJECT);
		g_once_init_leave (&gxml_ixsd_base_attribute_type_id__volatile, gxml_ixsd_base_attribute_type_id);
	}
	return gxml_ixsd_base_attribute_type_id__volatile;
}


static void gxml_ixsd_attribute_base_init (GXmlIXsdAttributeIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
	}
}


GType gxml_ixsd_attribute_get_type (void) {
	static volatile gsize gxml_ixsd_attribute_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_attribute_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdAttributeIface), (GBaseInitFunc) gxml_ixsd_attribute_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_attribute_type_id;
		gxml_ixsd_attribute_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdAttribute", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_attribute_type_id, G_TYPE_OBJECT);
		g_once_init_leave (&gxml_ixsd_attribute_type_id__volatile, gxml_ixsd_attribute_type_id);
	}
	return gxml_ixsd_attribute_type_id__volatile;
}


static void gxml_ixsd_attribute_group_base_init (GXmlIXsdAttributeGroupIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
	}
}


GType gxml_ixsd_attribute_group_get_type (void) {
	static volatile gsize gxml_ixsd_attribute_group_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_attribute_group_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdAttributeGroupIface), (GBaseInitFunc) gxml_ixsd_attribute_group_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_attribute_group_type_id;
		gxml_ixsd_attribute_group_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdAttributeGroup", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_attribute_group_type_id, G_TYPE_OBJECT);
		g_once_init_leave (&gxml_ixsd_attribute_group_type_id__volatile, gxml_ixsd_attribute_group_type_id);
	}
	return gxml_ixsd_attribute_group_type_id__volatile;
}


GXmlDomElement* gxml_ixsd_list_get_item (GXmlIXsdList* self, gint index) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_LIST_GET_INTERFACE (self)->get_item (self, index);
}


void gxml_ixsd_list_append (GXmlIXsdList* self, GXmlDomElement* element) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_LIST_GET_INTERFACE (self)->append (self, element);
}


void gxml_ixsd_list_remove (GXmlIXsdList* self, gint index) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_LIST_GET_INTERFACE (self)->remove (self, index);
}


gint gxml_ixsd_list_index_of (GXmlIXsdList* self, GXmlDomElement* element) {
	g_return_val_if_fail (self != NULL, 0);
	return GXML_IXSD_LIST_GET_INTERFACE (self)->index_of (self, element);
}


GXmlDomElement* gxml_ixsd_list_get_element (GXmlIXsdList* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_IXSD_LIST_GET_INTERFACE (self)->get_element (self);
}


void gxml_ixsd_list_set_element (GXmlIXsdList* self, GXmlDomElement* value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_LIST_GET_INTERFACE (self)->set_element (self, value);
}


GType gxml_ixsd_list_get_items_type (GXmlIXsdList* self) {
	g_return_val_if_fail (self != NULL, 0UL);
	return GXML_IXSD_LIST_GET_INTERFACE (self)->get_items_type (self);
}


void gxml_ixsd_list_set_items_type (GXmlIXsdList* self, GType value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_LIST_GET_INTERFACE (self)->set_items_type (self, value);
}


GType gxml_ixsd_list_get_items_name (GXmlIXsdList* self) {
	g_return_val_if_fail (self != NULL, 0UL);
	return GXML_IXSD_LIST_GET_INTERFACE (self)->get_items_name (self);
}


void gxml_ixsd_list_set_items_name (GXmlIXsdList* self, GType value) {
	g_return_if_fail (self != NULL);
	GXML_IXSD_LIST_GET_INTERFACE (self)->set_items_name (self, value);
}


gint gxml_ixsd_list_get_length (GXmlIXsdList* self) {
	g_return_val_if_fail (self != NULL, 0);
	return GXML_IXSD_LIST_GET_INTERFACE (self)->get_length (self);
}


static void gxml_ixsd_list_base_init (GXmlIXsdListIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
		g_object_interface_install_property (iface, g_param_spec_object ("element", "element", "element", GXML_TYPE_DOM_ELEMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
		g_object_interface_install_property (iface, g_param_spec_gtype ("items-type", "items-type", "items-type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
		g_object_interface_install_property (iface, g_param_spec_gtype ("items-name", "items-name", "items-name", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
		g_object_interface_install_property (iface, g_param_spec_int ("length", "length", "length", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	}
}


GType gxml_ixsd_list_get_type (void) {
	static volatile gsize gxml_ixsd_list_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_list_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdListIface), (GBaseInitFunc) gxml_ixsd_list_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_list_type_id;
		gxml_ixsd_list_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdList", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_list_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (gxml_ixsd_list_type_id, GXML_TYPE_GOM_COLLECTION);
		g_once_init_leave (&gxml_ixsd_list_type_id__volatile, gxml_ixsd_list_type_id);
	}
	return gxml_ixsd_list_type_id__volatile;
}


static void gxml_ixsd_list_elements_base_init (GXmlIXsdListElementsIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
	}
}


GType gxml_ixsd_list_elements_get_type (void) {
	static volatile gsize gxml_ixsd_list_elements_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_list_elements_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdListElementsIface), (GBaseInitFunc) gxml_ixsd_list_elements_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_list_elements_type_id;
		gxml_ixsd_list_elements_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdListElements", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_list_elements_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (gxml_ixsd_list_elements_type_id, GXML_TYPE_IXSD_LIST);
		g_once_init_leave (&gxml_ixsd_list_elements_type_id__volatile, gxml_ixsd_list_elements_type_id);
	}
	return gxml_ixsd_list_elements_type_id__volatile;
}


static void gxml_ixsd_list_simple_types_base_init (GXmlIXsdListSimpleTypesIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
	}
}


GType gxml_ixsd_list_simple_types_get_type (void) {
	static volatile gsize gxml_ixsd_list_simple_types_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_list_simple_types_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdListSimpleTypesIface), (GBaseInitFunc) gxml_ixsd_list_simple_types_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_list_simple_types_type_id;
		gxml_ixsd_list_simple_types_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdListSimpleTypes", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_list_simple_types_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (gxml_ixsd_list_simple_types_type_id, GXML_TYPE_IXSD_LIST);
		g_once_init_leave (&gxml_ixsd_list_simple_types_type_id__volatile, gxml_ixsd_list_simple_types_type_id);
	}
	return gxml_ixsd_list_simple_types_type_id__volatile;
}


static void gxml_ixsd_list_complex_types_base_init (GXmlIXsdListComplexTypesIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
	}
}


GType gxml_ixsd_list_complex_types_get_type (void) {
	static volatile gsize gxml_ixsd_list_complex_types_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_list_complex_types_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdListComplexTypesIface), (GBaseInitFunc) gxml_ixsd_list_complex_types_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_list_complex_types_type_id;
		gxml_ixsd_list_complex_types_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdListComplexTypes", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_list_complex_types_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (gxml_ixsd_list_complex_types_type_id, GXML_TYPE_IXSD_LIST);
		g_once_init_leave (&gxml_ixsd_list_complex_types_type_id__volatile, gxml_ixsd_list_complex_types_type_id);
	}
	return gxml_ixsd_list_complex_types_type_id__volatile;
}


static void gxml_ixsd_list_attributes_base_init (GXmlIXsdListAttributesIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
	}
}


GType gxml_ixsd_list_attributes_get_type (void) {
	static volatile gsize gxml_ixsd_list_attributes_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_list_attributes_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdListAttributesIface), (GBaseInitFunc) gxml_ixsd_list_attributes_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_list_attributes_type_id;
		gxml_ixsd_list_attributes_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdListAttributes", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_list_attributes_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (gxml_ixsd_list_attributes_type_id, GXML_TYPE_IXSD_LIST);
		g_once_init_leave (&gxml_ixsd_list_attributes_type_id__volatile, gxml_ixsd_list_attributes_type_id);
	}
	return gxml_ixsd_list_attributes_type_id__volatile;
}


static void gxml_ixsd_list_attributes_group_base_init (GXmlIXsdListAttributesGroupIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
	}
}


GType gxml_ixsd_list_attributes_group_get_type (void) {
	static volatile gsize gxml_ixsd_list_attributes_group_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_list_attributes_group_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdListAttributesGroupIface), (GBaseInitFunc) gxml_ixsd_list_attributes_group_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_list_attributes_group_type_id;
		gxml_ixsd_list_attributes_group_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdListAttributesGroup", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_list_attributes_group_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (gxml_ixsd_list_attributes_group_type_id, GXML_TYPE_IXSD_LIST);
		g_once_init_leave (&gxml_ixsd_list_attributes_group_type_id__volatile, gxml_ixsd_list_attributes_group_type_id);
	}
	return gxml_ixsd_list_attributes_group_type_id__volatile;
}


static void gxml_ixsd_list_type_restriction_enumerations_base_init (GXmlIXsdListTypeRestrictionEnumerationsIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
	}
}


GType gxml_ixsd_list_type_restriction_enumerations_get_type (void) {
	static volatile gsize gxml_ixsd_list_type_restriction_enumerations_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_list_type_restriction_enumerations_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdListTypeRestrictionEnumerationsIface), (GBaseInitFunc) gxml_ixsd_list_type_restriction_enumerations_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_list_type_restriction_enumerations_type_id;
		gxml_ixsd_list_type_restriction_enumerations_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdListTypeRestrictionEnumerations", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_list_type_restriction_enumerations_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (gxml_ixsd_list_type_restriction_enumerations_type_id, GXML_TYPE_IXSD_LIST);
		g_once_init_leave (&gxml_ixsd_list_type_restriction_enumerations_type_id__volatile, gxml_ixsd_list_type_restriction_enumerations_type_id);
	}
	return gxml_ixsd_list_type_restriction_enumerations_type_id__volatile;
}


static void gxml_ixsd_list_type_restriction_white_spaces_base_init (GXmlIXsdListTypeRestrictionWhiteSpacesIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
	}
}


GType gxml_ixsd_list_type_restriction_white_spaces_get_type (void) {
	static volatile gsize gxml_ixsd_list_type_restriction_white_spaces_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_ixsd_list_type_restriction_white_spaces_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlIXsdListTypeRestrictionWhiteSpacesIface), (GBaseInitFunc) gxml_ixsd_list_type_restriction_white_spaces_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_ixsd_list_type_restriction_white_spaces_type_id;
		gxml_ixsd_list_type_restriction_white_spaces_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlIXsdListTypeRestrictionWhiteSpaces", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_ixsd_list_type_restriction_white_spaces_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (gxml_ixsd_list_type_restriction_white_spaces_type_id, GXML_TYPE_IXSD_LIST);
		g_once_init_leave (&gxml_ixsd_list_type_restriction_white_spaces_type_id__volatile, gxml_ixsd_list_type_restriction_white_spaces_type_id);
	}
	return gxml_ixsd_list_type_restriction_white_spaces_type_id__volatile;
}



